﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
//import Qt.labs.shaders 1.0

AbstractPage {
    id: root

    property variant linkMenu: null
    property alias visualParent: menu.visualParent
    property StateGroup currentPlugin
    currentPluginLoading: currentPlugin ? currentPlugin.loading : false

    function message(text, icon) {
        infoBanners.message({'iconSource': icon, 'text': text})
    }

    Timer {
        running: typeof currentPlugin === 'object' && currentPlugin !== null && !currentPlugin.loading
        repeat: false
        interval: 10
        onTriggered: {
            var text = root.currentPlugin.message
            var icon = root.currentPlugin.icon
            if (text.length > 0)
                infoBanners.message({'text': text, 'iconSource': icon})
            root.currentPlugin = null
        }
    }

    signal headerClicked()

    function openLink(link, parameters) {
        console.debug(link)
        switch (true) {
        case /^search:\/\//.test(link):
            console.log(link.substring(9))
            pageStack.push(searchPage, {'id_str': link.substring(9)})
            break
        case /^user:\/\//.test(link):
            pageStack.push(userPage, {'id_str': link.substring(7)})
            break
        case /^status:/.test(link):
            pageStack.push(statusPage, {'id_str': link.substring(8)})
            break
        default:
            if (!root.linkMenu) {
                root.linkMenu = menu
                menu.link = link
                if (typeof parameters === 'undefined')
                    parameters = {'openLink': true }
                else
                    parameters.openLink = true
                menu.parameters = parameters
                menu.open()
            }
            break
        }
    }

    Menu {
        id: menu
        property string tweetText
        property url link
        property variant parameters

        MenuLayout {
            id: layout
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-l-browser-main-view'
                text: qsTr('Open in the browser')
                onClicked: {
                    root.running = true
                    Qt.openUrlExternally(menu.link)
                }
            }

            MenuItemWithIcon {
                property string api: 'https://www.instapaper.com/api/add'

                iconSource: 'qrc:/qml/rocket/images/instapaper.png'
                text: qsTr('Add to Instapaper')
                visible: {
                    if (settings.readData('instapaper.com/username', '').length === 0 && settings.readData('instapaper.com/password', '').length === 0)
                        return false;
                    else
                        return true;
                }
                onClicked: {
                    root.running = true

                    var username = settings.readData('instapaper.com/username', '')
                    var password = settings.readData('instapaper.com/password', '')
                    if (username.length === 0 || password.length === 0) {
                        pageStack.push(instapaperPage);
                        return
                    }

                    var url = api.concat('?username=').concat(username).concat('&password=').concat(password).concat('&url=').concat(menu.link)
                    var request = new XMLHttpRequest();
                    request.open('GET', url);
                    request.onreadystatechange = function() {
                        request.onreadystatechange = function() {
                            switch (request.readyState) {
                            case XMLHttpRequest.HEADERS_RECEIVED:
                                break
                            case XMLHttpRequest.LOADING:
                                break
                            case XMLHttpRequest.DONE: {
                                if (request.status == 200 || request.status == 201) {
                                    infoBanners.message("Link added to Instapaper")
                                } else {
                                    infoBanners.message("ERROR: "+request.responseText)
                                }
                                break }
                            case XMLHttpRequest.ERROR: {
                                infoBanners.message("ERROR: "+request.responseText)
                                break }
                            }
                        }
                    }
                    request.send();
                }
            }

            MenuItemWithIcon {
                property string pocketAPI: 'https://readitlaterlist.com/v2/add'
                property string apiKey: 'ebyd2r39Tdk37q14fuAy768t27g2I889'

                iconSource: 'qrc:/qml/rocket/images/getpocket.png'
                text: qsTr('Add to Pocket')
                visible: {
                    if (settings.readData('getpocket.com/username', '').length === 0 && settings.readData('getpocket.com/password', '').length === 0)
                        return false;
                    else
                        return true;
                }
                onClicked: {
                    root.running = true

                    var username = settings.readData('getpocket.com/username', '')
                    var password = settings.readData('getpocket.com/password', '')
                    if (username.length === 0 || password.length === 0) {
                        pageStack.push(pocketPage);
                        return
                    }

                    var url = pocketAPI.concat('?username=').concat(username).concat('&password=').concat(password).concat('&apikey=').concat(apiKey).concat('&url=').concat(menu.link)
                    var request = new XMLHttpRequest();
                    request.open('GET', url);
                    request.onreadystatechange = function() {
                        request.onreadystatechange = function() {
                            switch (request.readyState) {
                            case XMLHttpRequest.HEADERS_RECEIVED:
                                break
                            case XMLHttpRequest.LOADING:
                                break
                            case XMLHttpRequest.DONE: {
                                if (request.status == 200) {
                                    infoBanners.message("Link added to Pocket")
                                } else {
                                    infoBanners.message("ERROR: "+request.responseText)
                                }
                                break }
                            case XMLHttpRequest.ERROR: {
                                infoBanners.message("ERROR: "+request.responseText)
                                break }
                            }
                        }
                    }
                    request.send();
                }
            }

            MenuItemWithIcon {
                property string deliciousAPI: 'https://%1:%2@api.del.icio.us/v1/posts/add?url=%3&description=%4'

                iconSource: 'qrc:/qml/rocket/images/delicious.png'
                text: qsTr('Add to Delicious')
                visible: {
                    if (settings.readData('api.del.icio.us/username', '').length === 0 && settings.readData('api.del.icio.us/password', '').length === 0)
                        return false;
                    else
                        return true;
                }
                onClicked: {
                    root.running = true

                    var username = settings.readData('api.del.icio.us/username', '')
                    var password = settings.readData('api.del.icio.us/password', '')
                    if (username.length === 0 || password.length === 0) {
                        pageStack.push(deliciousPage);
                        return
                    }

                    var deliciousUrl = 'https://'+username+':'+password+'@api.del.icio.us/v1/posts/add?url='+menu.link+'&description='+menu.link;
                    console.log(deliciousUrl)
                    var request = new XMLHttpRequest();
                    request.open('GET', deliciousUrl);
                    request.onreadystatechange = function() {
                            switch (request.readyState) {
                            case XMLHttpRequest.HEADERS_RECEIVED:
                                break
                            case XMLHttpRequest.LOADING:
                                break
                            case XMLHttpRequest.DONE: {
                                if (request.status == 200) {
                                    infoBanners.message("Link added to Delicious")
                                } else {
                                    infoBanners.message("ERROR: "+request.responseText)
                                }
                                break }
                            case XMLHttpRequest.ERROR: {
                                infoBanners.message("ERROR: "+request.responseText)
                                break }
                            }
                    }
                    request.send();
                }
            }

            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-tag'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Copy to clipboard')
                onClicked: {
                    clipboard.text = '';
                    clipboard.text = menu.link;
                    clipboard.selectAll();
                    clipboard.cut();
                }
            }
        }
        property bool __completed: false
        onStatusChanged: {
            if (menu.__completed && menu.status === DialogStatus.Closed) {
                root.linkMenu = null
            }
        }
        Component.onCompleted: menu.__completed = true
    }
}
