/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import "../Delegates"

ListView {
    id: root
    width: 52
    height: 52
    clip: true
    orientation: ListView.Horizontal;

    property bool icon: false
    property string filter
    signal clicked(string candidate)

    Button {
        id: button
        visible: false
    }

    property bool __dialogButton: false
    property bool checked: false
    property bool checkable: false

    delegate: Image {
        id: delegate
        width: active ? (constants.showAutocompleteAvatars ? userName.width+100 : userName.width+30) : 0
        height: active ? (constants.showAutocompleteAvatars ? 52 : 48) : 0
        property bool active: model.screen_name.substring(0, root.filter.length - 1).toLowerCase() === root.filter.substring(1).toLowerCase()
        clip: true

        BorderImage {
            id: background
            anchors.fill: parent
            border { left: button.platformStyle.backgroundMarginLeft; top: button.platformStyle.backgroundMarginTop;
                     right: button.platformStyle.backgroundMarginRight; bottom: button.platformStyle.backgroundMarginBottom }

            source:  __dialogButton ? (pressed ? button.platformStyle.pressedDialog : button.platformStyle.dialog) :
                      !enabled ?
                      (checked ? button.platformStyle.checkedDisabledBackground : button.platformStyle.disabledBackground) :
                      checked ? button.platformStyle.checkedBackground : button.platformStyle.background;
        }

        Image {
            id: avatar

            property string imageSource: constants.showAutocompleteAvatars ? 'http://api.twitter.com/1/users/profile_image?screen_name='.concat(model.screen_name) : ''

            anchors.left: parent.left
            anchors.leftMargin: 17
            anchors.verticalCenter: parent.verticalCenter
            width: constants.showAutocompleteAvatars ? 48 : 0
            height: 48
            visible: delegate.active

            function loadImage() {
                if (source == "") {
                    avatar.source = thumbnailCacher.get(avatar.imageSource) || (networkConfigurationManager.online ? avatar.imageSource : avatar.imageSource)
                }
            }

            onStatusChanged: {
                if(status == Image.Ready){
                    if(source == avatar.imageSource)
                        thumbnailCacher.cache(avatar.imageSource, avatar)
                }
            }

            Component.onCompleted: {
                avatar.loadImage();
            }
        }

        Text {
            id: userName
            anchors.left: avatar.right
            anchors.leftMargin: constants.showAutocompleteAvatars ? constants.listViewMargins : 0
            anchors.verticalCenter: parent.verticalCenter
            font.bold: true
            font.pixelSize: 24
			color: constants.username_color
            text: (root.icon ? '@' : '#').concat(model.screen_name)
            elide: Text.ElideRight
            visible: active
        }
        MouseArea {
            id: mouseArea
            anchors {
                fill: parent
            }
            onClicked: root.clicked(model.screen_name)
        }
        //Component.onCompleted: mouseArea.clicked.connect(clicked)
        visible: delegate.active
    }
}
