/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import Rocket 1.0

QtObject {
    id: root

    property string version: '0.0.6 beta'

    property string fontFamily: "Nokia Pure Text";
    property int fontXLarge: fontDefault * 1.3
    property int fontLarge: fontDefault * 1.2
    property int fontSLarge: fontDefault * 1.1
    property int fontDefault: 24
    property int fontLSmall: fontDefault * 0.916
    property int fontSmall: fontDefault * 0.8
    property int fontXSmall: fontDefault * 0.7
    property int fontXXSmall: fontDefault * 0.6

    //property int headerHeight: (screen.currentOrientation == Screen.Portrait) ? 72 : 64;
    property int headerDefaultHeightInPortrait: 72
    property int headerDefaultHeightInLandscape: 64

    property int listViewMargins: 7
    property int listViewIconSize: 73
    property int listViewAvatar: 48
    property int listViewScrollbarWidth: 5

    property color separaterColor: '#FFFFFF'
    property color toMeSeparaterColor: '#FF33CA'
    property color fromMeSeparatorColor: '#33CAFF'

    property color color_background_d: theme.inverted ? "#444444" : "white"
    property color color_text_d: theme.inverted ? "white" : "#444444"
    property color user_background: theme.inverted ? "black" : "#d9d9d9"
    property color toolbar_topline1: theme.inverted ? "#0a0a0a" : "#838484"
    property color toolbar_topline2: theme.inverted ? "#262626" : "#ffffff"
    property color toolbar_grad_start: theme.inverted ? "#0c0c0c" : "#c8cacb"
    property color toolbar_grad_end: theme.inverted ? "#000000" : "#a0a3a3"

    property color timeline_topline: theme.inverted ? "#585858" : "#b7b7b7"
    property color timeline_bottomline: theme.inverted ? "#0c0c0c" : "transparent"
    property color timeline_grad_start: theme.inverted ? "#3c3c3c" : "#fdfdfd"
    property color timeline_grad_end: theme.inverted ? "#202020" : "#e5e5e5"

    property color username_color: theme.inverted ? "#f2f2f2" : "#313031" //"#f2f2f2" : "#000000"
    property color tweettext_color: theme.inverted ? "#c7c7c7" : "#313031" //"#c7c7c7" : "#292929"//454545
    property color tweetsince_color: theme.inverted ? "#feba44" : "#b5b2b5" //"#feba44" : "#672121"

    property string linkStyle: window.inPortrait ? root.linkStylePortrait : root.linkStyleLandscape
    property string linkStylePortrait: 'text-decoration: none; color: #4d6980'//#4a6984
    property string linkStyleLandscape: 'text-decoration: none; color: #4d6980'//#4a6984

    property string hashTagStyle: window.inPortrait ? root.hashTagStylePortrait : root.hashTagStyleLandscape
    property string hashTagStylePortrait: 'text-decoration: none; color: #4a6984'
    property string hashTagStyleLandscape: 'text-decoration: none; color: #4a6984'

    property string screenNameStyle: window.inPortrait ? root.screenNameStylePortrait : root.screenNameStyleLandscape
    property string screenNameStylePortrait: 'text-decoration: none; color: #4a6984'
    property string screenNameStyleLandscape: 'text-decoration: none; color: #4a6984'

    property string mediaStyle: window.inPortrait ? root.mediaStylePortrait : root.mediaStyleLandscape
    property string mediaStylePortrait: 'text-decoration: none; color: #4a6984'
    property string mediaStyleLandscape: 'text-decoration: none; color: #4a6984'

    property string sourceStyle: window.inPortrait ? root.sourceStylePortrait : root.sourceStyleLandscape
    property string sourceStylePortrait: 'text-decoration: none; color: gray'
    property string sourceStyleLandscape: 'text-decoration: none; color: gray'

    property ConfItem publishToEventFeedConf: ConfItem { id: publishToFeed; key: '/apps/ControlPanel/Rocket/EventFeedEnable' }
    property ConfItem mentionsNotificationConf: ConfItem { id: mentionsNotificationConf; key: '/apps/ControlPanel/Rocket/Notification/Mentions' }
    property ConfItem messagesNotificationConf: ConfItem { id: messagesNotificationConf; key: '/apps/ControlPanel/Rocket/Notification/DirectMessages' }
    property ConfItem followedByNotificationConf: ConfItem { id: followedByNotificationConf; key: '/apps/ControlPanel/Rocket/Notification/FollowedBy' }
    property bool publishToEventFeed: publishToEventFeedConf.value
    onPublishToEventFeedChanged: publishToEventFeedConf.value = root.publishToEventFeed
    property bool mentionsNotification: mentionsNotificationConf.value
    onMentionsNotificationChanged: mentionsNotificationConf.value = root.mentionsNotification
    property bool messagesNotification: messagesNotificationConf.value
    onMessagesNotificationChanged: messagesNotificationConf.value = root.messagesNotification
    property bool followedByNotification: followedByNotificationConf.value
    onFollowedByNotificationChanged: followedByNotificationConf.value = root.followedByNotification

    property bool notificationsWithHapticsFeedback: settings.readData('Notifications/HapticsFeedback', true)
    onNotificationsWithHapticsFeedbackChanged: settings.saveData('Notifications/HapticsFeedback', root.notificationsWithHapticsFeedback)

    property bool showSource: settings.readData('Timeline/showSource', false)
    property bool showSinceOnTop: settings.readData('Timeline/showSinceOnTop', true)
    property bool showAvatars: settings.readData('Timeline/showAvatars', true)
    property bool showAutocompleteAvatars: settings.readData('Autocomplete/showAutocompleteAvatars', false)

    property bool visualTheme: settings.readData('Application/visualTheme', false)
    property bool showStatusBar: settings.readData('Application/showStatusBar', true)
    property bool lockOrientation: settings.readData('Application/lockOrientation', false)
    property bool showUserAvatarFrame: settings.readData('Application/showUserAvatarFrame', false)
    property bool locationAlwaysOn: settings.readData('Application/locationAlwaysOn', false)
}
