/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import TwitterCore 1.0
//import Qt.labs.shaders 1.0
import '../Components'

MouseArea {
    id: root
    width: 400
    height: container.height

    property variant direct_message
    property variant sender
    property variant recipient

    property string imageSource: sender.profile_image_url;//'http://api.twitter.com/1/users/profile_image?screen_name='.concat(sender.screen_name).concat('&size=normal');

    signal linkActivated(string link)

    Item {
        id: container
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.rightMargin: constants.listViewScrollbarWidth
        anchors.bottom: parent.bottom
        height: Math.max(iconArea.height, statusArea.height) + 25

        Item {
            id: iconArea
            anchors.left: if (sender.id_str === oauth.user_id) return parent.left;
            anchors.right: if (sender.id_str !== oauth.user_id) return parent.right
            anchors.leftMargin: 16
            anchors.top: parent.top
            anchors.topMargin: 16
            anchors.rightMargin: 16
            width: constants.listViewAvatar
            height: width
            visible: settings.readData('Timeline/showAvatars', true)

            Image {
                id: icon
                anchors.fill: parent
                enabled: constants.showAvatars
                //source: iconArea.visible && sender && sender.screen_name ? 'http://api.twitter.com/1/users/profile_image?screen_name='.concat(sender.screen_name).concat('&size=normal') : ''

                function loadImage(){
                    if (source == "") {
                        icon.source = thumbnailCacher.get(root.imageSource) || (networkConfigurationManager.online ? root.imageSource : root.imageSource)
                    }
                }

                onStatusChanged: {
                    if (status == Image.Ready) {
                        if(source == root.imageSource)
                            thumbnailCacher.cache(root.imageSource, icon)
                    }
                }

                Component.onCompleted: {
                    icon.loadImage();
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: root.linkActivated('user:'.concat(sender.id_str))
            }
        }

        Column {
            id: statusArea
            anchors.left: {
                if (sender.id_str === oauth.user_id)
                    if (iconArea.visible)
                        return iconArea.right;
                    else
                        return parent.left;
                else
                    return parent.left;
            }
            anchors.right: {
                if (sender.id_str === oauth.user_id)
                    return parent.right;
                else
                    if (iconArea.visible)
                        return iconArea.left;
                    else
                        return parent.right;
            }
            anchors.top: parent.top
            anchors.topMargin: 13
            anchors.leftMargin: 16//constants.listViewMargins
            spacing: constants.listViewMargins

            Text {
                text: sender.screen_name ? sender.screen_name : ''
                font.family: constants.fontFamily
                font.pixelSize: constants.fontLSmall
                font.bold: true
                color: constants.username_color
                elide: Text.ElideRight;
            }

            Text {
                id: text
                text: direct_message.plain_text
                width: parent.width
                wrapMode: Text.WordWrap
                textFormat: Text.PlainText
                clip: true;
                color: constants.tweettext_color
                font.family: constants.fontFamily
                font.pixelSize: constants.fontLSmall
            }

            Row {
                anchors.right: parent.right
                visible: sender.id_str === oauth.user_id
                spacing: constants.listViewMargins

                Text {
                    text: 'Sent to'
                    anchors.bottom: parent.bottom
                    font.family: constants.fontFamily
                    font.pixelSize: constants.fontSmall
                    color: constants.username_color
                }

                Text {
                    anchors.bottom: parent.bottom
                    text: recipient.screen_name ? recipient.screen_name : ''
                    font.bold: true
                    font.family: constants.fontFamily
                    font.pixelSize: constants.fontSmall
                    color: constants.username_color
                }
            }
        }

        Rectangle {
            x: 0
            z: 99
            width: parent.width
            height: 1
            color: constants.timeline_topline
        }
    }
}
