/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import TwitterCore 1.0
//import Qt.labs.shaders 1.0
import '../Components'

MouseArea {
    id: root
    width: parent.width
    height: container.height
    property int height2: container.height

    property variant item
    property variant user

    property alias buttonRow: btnPane.visible
    property alias buttonRowH: btnPane.height

    property bool __retweeted: root.item !== undefined && item.retweeted_status !== undefined && item.retweeted_status.user !== undefined
    property variant __item: root.__retweeted ? root.item.retweeted_status : root.item

    property string imageSource: __item.user.profile_image_url;//'http://api.twitter.com/1/users/profile_image?screen_name='.concat(__item.user.screen_name).concat('&size=normal');

    signal linkActivated(string link)

    Status {
        id: status
        id_str: root.item.id_str
    }

    Connections {
        target: window.parent
        onOrientationChangeAboutToStart:  {
            if (btnPane.visible) {
                btnPane.visible = false;
                statusListView.openIndex = -1;
            }
        }
    }

    states: [
        State {
            name: "open"
            when: ((statusListView.openIndex != -1) && (statusListView.openIndex == index))
            PropertyChanges {
                target: btnPane
                visible: true
            }
        },
        State {
            name: "close"
            when: statusListView.openIndex != -1
            PropertyChanges {
                target: btnPane
                visible: false
            }
        }
    ]

    Item {
        id: container
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.rightMargin: constants.listViewScrollbarWidth
        anchors.bottom: parent.bottom
        height: Math.max(iconArea.height, statusArea.height) + 25

        Item {
            id: iconArea
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.top: parent.top
            anchors.topMargin: 16
            width: constants.listViewAvatar
            height: width
            visible: settings.readData('Timeline/showAvatars', true)

            Image {
                id: icon
                anchors.fill: parent
                enabled: constants.showAvatars
                //source: iconArea.visible && __item && __item.user.screen_name ? 'http://api.twitter.com/1/users/profile_image?screen_name='.concat(__item.user.screen_name).concat('&size=normal') : ''

                function loadImage(){
                    if (source == "") {
                        icon.source = thumbnailCacher.get(root.imageSource) || (networkConfigurationManager.online ? root.imageSource : root.imageSource)
                    }
                }

                onStatusChanged: {
                    if(status == Image.Ready){
                        if(source == root.imageSource)
                            thumbnailCacher.cache(root.imageSource, icon)
                    }
                }

                Component.onCompleted: {
                    if(!root.ListView.view || !root.ListView.view.moving)
                        icon.loadImage()
                }

                Connections{
                    target: root.ListView.view ? networkConfigurationManager : null
                    onOnlineChanged: if(test.online && !root.ListView.view.moving)
                        icon.loadImage()
                }

                Connections{
                    target: root.ListView.view
                    onMovingChanged: if(!root.ListView.view.moving)
                        icon.loadImage()
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.linkActivated('user://'.concat(__item.user.id_str))
                }
            }
        }

        Text {
            id: lblSinceTop
            anchors.top: parent.top
            anchors.topMargin: 17
            anchors.rightMargin: 17
            anchors.right: parent.right
            font.family: constants.fontFamily
            font.pixelSize: constants.fontDefault*0.75
            visible: settings.readData('Timeline/showSinceOnTop', true)
            text: {
                var oToday = new Date(); // текущая дата
                var oDeadLineDate = new Date(__item.created_at); // собственно устанавливаем «час Икс»
                var nDaysLeft = oDeadLineDate < oToday ? Math.ceil((oToday - oDeadLineDate) / (1000)) : null; // а тут мы вычисляем, сколько же осталось дней — находим разницу в миллисекундах и переводим её в дни

                if (nDaysLeft < 0)
                        return "now";

                if (nDaysLeft < 60)
                    return qsTr("%1 s. ago").arg(Math.ceil(nDaysLeft));

                if (nDaysLeft < 3600)
                    return qsTr("%1 m. ago").arg(Math.ceil(nDaysLeft / 60));

                if (nDaysLeft < 86400)
                    return qsTr("%1 h. ago").arg(Math.ceil(nDaysLeft / 3600));

                return Qt.formatDateTime(new Date(__item.created_at), 'dd.MM.yyyy');
            }
            color: 'gray'
        }

        Column {
            id: statusArea
            anchors.left: iconArea.visible ? iconArea.right : parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.topMargin: 13
            spacing: constants.listViewMargins

            Row {
                id: topRow
                spacing: 5
                Text {
                    id: lblName
                    text: __item.user && __item.user.screen_name ? __item.user.screen_name : ''
                    font.family: constants.fontFamily
                    font.pixelSize: constants.fontLSmall
                    font.bold: true
                    color: constants.username_color
                }

                Image {
                    anchors.verticalCenter: parent.verticalCenter
                    source: '../images/retweeted.png'
                    visible: root.__retweeted
                }

                Text {
                    id: retweetedName
                    anchors.verticalCenter: parent.verticalCenter
                    text: user.screen_name ? user.screen_name : ''
                    font.family: constants.fontFamily
                    font.pixelSize: constants.fontLSmall
                    font.bold: true
                    color: constants.username_color
                    visible: root.__retweeted
                }
            }

            Connections {
                target: translateTweet
                onFinishedTranslatingTweet: {
                    var temp = text.text;
                    text.text = translatedText;
                    console.log("Text translated: " + translatedText);
                }
            }

            Text {
                id: text
                width: parent.width
                wrapMode: Text.WordWrap
                textFormat: Text.PlainText
                text: __item ? __item.plain_text : ''
                clip: true;
                color: constants.tweettext_color
                font.family: constants.fontFamily
                font.pixelSize: constants.fontLSmall
            }

            Rectangle {
                z: 99999
                id: btnPane
                height: 0
                width: parent.width
                visible: false
                color: "transparent"
                onVisibleChanged: {
                    if (btnPane.visible) {
                        btnPane.height = 72;
                    } else {
                        btnPane.height = 0;
                    }
                }

                Row {
                    id: btnRow
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    spacing: 20
                    TimelineButton {
                        id: btnReply
                        anchors.verticalCenter: parent.verticalCenter
                        iconSource: theme.inverted ? '../images/reply-white.png' : '../images/reply-white.png' //TODO: Then added white background, fix this
                        onClicked: {
                            btnPane.visible = false;
                            var user = '@' + __item.user.screen_name
                            var users = __item.text.match(/@[A-Za-z0-9_]+/g)
                            var statusText = user + ' '
                            if (users) {
                                for (var i = 0; i < users.length; i++) {
                                    if (users[i] !== user && users[i] !== '@' + oauth.screen_name && statusText.indexOf(users[i]) < 0)
                                        statusText += users[i] + ' '
                                }
                            }

                            pageStack.push(tweetPage, {'statusText': statusText, 'in_reply_to': __item})
                        }
                    }

                    TimelineButton {
                        id: btnFavorite
                        anchors.verticalCenter: parent.verticalCenter
                        iconSource: 'image://theme/icon-m-toolbar-favorite-unmark'.concat(theme.inverted ? "-white" : "-white") //TODO: Then added white background, fix this
                        onClicked: {
                            btnPane.visible = false;
                            if (status.favorited)
                                status.unfavorite();
                            else
                                status.favorite();
                        }
                        states: [
                            State {
                                name: "favorited"
                                when: __item.favorited
                                PropertyChanges {
                                    target: btnFavorite
                                    iconSource: 'image://theme/icon-m-toolbar-favorite-mark'.concat(theme.inverted ? "-white" : "")
                                }
                            }
                        ]
                    }

                    TimelineButton {
                        id: btnRetweet
                        anchors.verticalCenter: parent.verticalCenter
                        enabled: !__item.retweeted
                        opacity: enabled ? 1.0 : 0.5
                        iconSource: theme.inverted ? '../images/retweet-white.png' : '../images/retweet-white.png' //TODO: Then added white background, fix this
                        onClicked: {
                            btnPane.visible = false;
                            if (root.linkMenu) root.linkMenu.close()
                            menu.close()
                            if (__item.user.id_str == oauth.user_id || __item.retweeted) {
                                pageStack.push(tweetPage, {'statusText': ' RT @' + __item.user.screen_name + ': ' + __item.text, 'in_reply_to': __item})
                            } else {
                                pageStack.push(tweetPage, {'in_reply_to': __item})
                            }
                        }
                    }
                }
            }
        }

        Rectangle {
            x: 0
            z: 99
            width: parent.width
            height: 1
            color: constants.timeline_topline
        }
    }
}
