/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import '../Components/'

MouseArea {
    id: root
    width: parent.width
    height: container.height

    property bool temporary: false
    property variant item
    property variant user

    property bool retweeted: item.retweeted_status !== undefined && item.retweeted_status.user !== undefined
    property variant __item: retweeted ? item.retweeted_status : item
    property bool __favorited: __item.favorited

    property string imageSource: __item.user.profile_image_url.replace("_normal", "_bigger");//'http://api.twitter.com/1/users/profile_image?screen_name='.concat(__item.user.screen_name).concat('&size=bigger');

    signal userClicked(variant user)
    signal linkActivated(string link)

    Item {
        id: container
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.rightMargin: constants.listViewScrollbarWidth
        height: detailArea.y + detailArea.height + 12
        clip: true

        MouseArea {
            id: userArea
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: Math.max(iconArea.height, nameArea.height) + 12
            Item {
                id: iconArea
                anchors.left: parent.left
                anchors.leftMargin: 12
                anchors.top: parent.top
                anchors.topMargin: 12
                width: 73
                height: width

                Image {
                    id: icon
                    anchors.fill: parent
                    //source: root.temporary ? '' : (__item.user.profile_image_url ? 'http://api.twitter.com/1/users/profile_image?screen_name='.concat(__item.user.screen_name).concat('&size=bigger') : '')

                    function loadImage(){
                        if (source == "") {
                            icon.source = thumbnailCacher.get(root.imageSource) || (networkConfigurationManager.online ? root.imageSource : root.imageSource)
                        }
                    }

                    onStatusChanged: {
                        if (status == Image.Ready) {
                            if(source == root.imageSource)
                                thumbnailCacher.cache(root.imageSource, icon)
                        }
                    }

                    Component.onCompleted: {
                        icon.loadImage();
                    }
                }
            }

            Rectangle {
                id: nameArea
                anchors.left: iconArea.right
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.top: iconArea.top
                color: "transparent"
                Label {
                    id: lblScreenName
                    anchors.top: parent.top
                    anchors.topMargin: 4
                    anchors.left: nameArea.left
                    text: __item.user && __item.user.screen_name ? __item.user.screen_name : ''
                    font.bold: true
                    platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                }
                Label {
                    anchors.top: lblScreenName.bottom
                    anchors.left: nameArea.left
                    text: __item.user && __item.user.name ? __item.user.name : ''
                    platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                }
            }

            Image {
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                source: 'image://theme/icon-m-common-drilldown-arrow'.concat(theme.inverted ? "-inverse" : "")
            }
            onClicked: root.userClicked(__item.user)
        }

        Column {
            id: detailArea
            anchors.top: userArea.bottom
            anchors.topMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 17
            anchors.right: parent.right
            anchors.rightMargin: 17
            spacing: constants.listViewMargins

            Label {
                width: parent.width
                wrapMode: Text.WordWrap
                textFormat: Text.RichText
                text: qsTr('<style type="text/css">a.link{%2} a.screen_name{%3} a.hash_tag{%4} a.media{%5}</style>%1').arg(__item.rich_text).arg(constants.linkStyle).arg(constants.screenNameStyle).arg(constants.hashTagStyle).arg(constants.mediaStyle).arg(parent.width)
                font.pixelSize: constants.fontDefault
                onLinkActivated: root.linkActivated(link)
            }

            Row {
                anchors.left: parent.left
                spacing: constants.listViewMargins

                Label {
                    text: __item.created_at ? Qt.formatDateTime(new Date(__item.created_at), 'dd.MM.yyyy hh:mm') : ''
                    color: constants.tweettext_color
                    platformStyle: LabelStyle {
                        fontPixelSize: constants.fontSmall
                    }
                }
            }

            Row {
                anchors.left: parent.left
                spacing: constants.listViewMargins

                Label {
                    text: qsTr('<style type="text/css">a{%2}</style>%1').arg(__item.source).arg(constants.sourceStyle)
                    platformStyle: LabelStyle { fontPixelSize: constants.fontSmall }
                }
            }

            Row {
                anchors.right: parent.right
                visible: __retweeted
                spacing: constants.listViewMargins

                Image {
                    source: theme.inverted ? '../images/retweet-white.png' : '../images/retweet.png'
                    anchors.verticalCenter: parent.verticalCenter
                    MouseArea {
                        anchors.fill: parent
                        onClicked: root.userClicked(user)
                    }
                }

                Label {
                    anchors.bottom: parent.bottom
                    text: user.screen_name ? user.screen_name : ''
                    platformStyle: LabelStyle { fontPixelSize: constants.fontSmall }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: root.userClicked(user)
                    }
                }
            }
        }
    }
}
