/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0

MouseArea {
    id: root
    width: 400
    height: container.height
    property int height2: container.height

    property variant user

    property string imageSource: user.profile_image_url;

    Item {
        id: container
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.rightMargin: constants.listViewScrollbarWidth
        anchors.bottom: parent.bottom
        height: Math.max(iconArea.height, statusArea.height) + 25

        Item {
            id: iconArea
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.top: parent.top
            anchors.topMargin: 16
            anchors.rightMargin: 16
            width: constants.listViewAvatar
            height: width
            visible: settings.readData('Timeline/showAvatars', true)

            Image {
                id: icon
                anchors.fill: parent
                enabled: constants.showAvatars
                //source: iconArea.visible ? user.profile_image_url : ''

                function loadImage(){
                    if (source == "") {
                        icon.source = thumbnailCacher.get(root.imageSource) || (networkConfigurationManager.online ? root.imageSource : root.imageSource)
                    }
                }

                onStatusChanged: {
                    if (status == Image.Ready) {
                        if(source == root.imageSource)
                            thumbnailCacher.cache(root.imageSource, icon)
                    }
                }

                Component.onCompleted: {
                    icon.loadImage();
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.linkActivated('user://'.concat(__item.user.id_str))
                }
            }
        }

        Column {
            id: statusArea
            anchors.left: iconArea.visible ? iconArea.right : parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.topMargin: 13
            anchors.leftMargin: 16
            anchors.bottomMargin: 13
            spacing: constants.listViewMargins

                Label {
                id: lblName
                text: user && user.screen_name ? user.screen_name : ''
                platformStyle: LabelStyle { fontPixelSize: constants.fontLSmall }
                    font.bold: true
                color: constants.username_color
                elide: Text.ElideRight;
                }

                Label {
                    id: text
                    width: parent.width
                    wrapMode: Text.WordWrap
                    textFormat: Text.PlainText
                    text: user.description//.replace(/\r\n/g, "<br>")
                    clip: true;
                    color: constants.tweettext_color
                    platformStyle: LabelStyle { fontPixelSize: constants.fontLSmall }
                }
            }

        Rectangle {
            x: 0
            z: 99
                width: parent.width
            height: 1
            color: constants.timeline_topline
            }

        Rectangle {
            x: 0
            y: parent.height-1
            z: 99
            width: parent.width
            height: 1
            color: constants.timeline_bottomline
        }
    }
}
