﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: root
    width: parent.width
    z: 3
    height: container.height

    property variant user

    property string imageSource: ""
    property bool isLoaded: false
    property bool bannerIsLoaded: false
    property string bannerSource: "";

    signal userClicked(variant user)
    signal linkActivated(string link)

    Connections {
        target: window.parent
        onOrientationChangeAboutToStart:  {
            if (screen.currentOrientation === Screen.Portrait)
                root.bannerSource = user.profile_banner_url+"/web";
            else
                root.bannerSource = user.profile_banner_url+"/mobile_retina";
            userBannerImage.loadImage();
        }
    }

    Item {
        id: container
        anchors.left: parent.left
        anchors.right: parent.right
        height: userArea.height//parent.height// + 10 + 2

        Rectangle {
            anchors.fill: parent
            color: constants.user_background
        }

        Item {
            id: userArea
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: userBannerImage.height + userNameFrame.height + userBioFrame.height + frameContactInfo.height // - constants.listViewScrollbarWidth * 2 //height: Math.max(iconAreaFrame.height, userBannerImage.height) + constants.listViewScrollbarWidth * 2

            Image {
                id: userBannerImage
                width: parent.width
                height: width/2
                smooth: true
                clip: true
                fillMode: Image.Stretch;

                states: [
                    State {
                        name: "updatesource"
                        when: (user.profile_banner_url != "")//&&(bannerIsLoaded == false)
                        StateChangeScript  {
                            script: {
                                bannerIsLoaded = true;
                                root.bannerSource = (screen.currentOrientation === Screen.Portrait) ? user.profile_banner_url+"/web" : user.profile_banner_url+"/mobile_retina";
                                userBannerImage.loadImage();
                            }
                        }
                    }
                ]

                function loadImage() {
                    if (source == "") {
                        userBannerImage.source = thumbnailCacher.get(root.bannerSource) || (networkConfigurationManager.online ? root.bannerSource : root.bannerSource)
                    }
                }

                onStatusChanged: {
                    if(status == Image.Ready){
                        if(source == root.bannerSource)
                            thumbnailCacher.cache(root.bannerSource, userBannerImage)
                    }
                }

                Component.onCompleted: {
                    userBannerImage.loadImage();
                }
            }

            states: [
                State {
                    name: "landscape"
                    when: screen.currentOrientation === Screen.Landscape
                    PropertyChanges {
                        target: userBannerImage
                        height: 170
                    }
                    PropertyChanges {
                        target: userBannerImage
                        fillMode: Image.PreserveAspectCrop
                    }
                }
            ]
            
            Rectangle {
                anchors.top: userBannerImage.bottom
                anchors.bottom: userBioFrame.bottom
                width: parent.width
                gradient: Gradient {
                    GradientStop {
                        color: theme.inverted ? "#393939" : "#c6c6c6"
                        position: 0
                    }
                    GradientStop {
                        color: theme.inverted ? "#252525" : "#dadada"
                        position: 1
                    }
                }
                Rectangle {
                    anchors.top: parent.top
                    height: 1
                    width: parent.width
                    color: theme.inverted ? "#000000" : "#ffffff"
                }
                Rectangle {
                    anchors.top: parent.top
                    anchors.topMargin: 1
                    height: 1
                    width: parent.width
                    color: theme.inverted ? "#494949" : "#b6b6b6"
                }
            }

            Rectangle {
                id: userNameFrame
                anchors.top: userBannerImage.bottom
                height: 54
                width: parent.width
                color: "transparent"
                /*gradient: Gradient {
                    GradientStop {
                        color: "#393939"
                        position: 0
                    }
                    GradientStop {
                        color: "#252525"
                        position: 1
                    }
                }
                Rectangle {
                    anchors.top: parent.top
                    height: 1
                    width: parent.width
                    color: "#000000"
                }
                Rectangle {
                    anchors.top: parent.top
                    anchors.topMargin: 1
                    height: 1
                    width: parent.width
                    color: "#494949"
                }*/
            }

            Rectangle {
                id: iconAreaFrame
                anchors {
                    left: iconArea.left
                    leftMargin: -5
                    top: iconArea.top
                    topMargin: -5
                }
                width: iconArea.width+10
                height: iconArea.height+10
                color: "white"
                radius: 5
                visible: constants.showUserAvatarFrame;
            }

            Item {
                id: iconArea
                anchors.left: parent.left
                /*anchors.leftMargin: 12
                anchors.top: parent.top
                anchors.topMargin: 12*/
                anchors.leftMargin: 18
                anchors.top: userBannerImage.bottom
                anchors.topMargin: -24
                width: constants.listViewIconSize
                height: width
                Image {
                    id: icon
                    anchors.fill: parent

                    states: [
                        State {
                            name: "updatesource"
                            when: (user.screen_name != "")&&(isLoaded == false)
                            StateChangeScript  {
                                script: {
                                    isLoaded = true;
                                    root.imageSource = user.profile_image_url.replace("_normal", "_bigger"); // 'http://api.twitter.com/1/users/profile_image?screen_name='.concat(user.screen_name).concat('&size=bigger');
                                    icon.loadImage();
                                }
                            }
                        }
                    ]

                    function loadImage() {
                        console.log("root.imageSource " + root.imageSource);
                        if (source == "") {
                            icon.source = thumbnailCacher.get(root.imageSource) || (networkConfigurationManager.online ? root.imageSource : root.imageSource)
                        }
                    }

                    onStatusChanged: {
                        if (status == Image.Ready) {
                            if(source == root.imageSource)
                                thumbnailCacher.cache(root.imageSource, icon)
                        }
                    }

                    Component.onCompleted: {
                        icon.loadImage();
                    }

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            pageStack.push(previewPage, {url: user.profile_image_url.replace("_normal", "") })//'http://api.twitter.com/1/users/profile_image?screen_name='.concat(user.screen_name).concat('&size=original')
                        }
                    }
                }
            }

            Label {
                id: lblNameShadow
                /*anchors.top: parent.top
                anchors.topMargin: 1
                anchors.left: iconArea.right
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12
                elide: Text.ElideRight
                horizontalAlignment: Text.AlignRight*/
                anchors.top: userNameFrame.top
                anchors.topMargin: userNameFrame.height/2 - lblNameShadow.height/2 + 2
                anchors.left: iconArea.right
                anchors.leftMargin: 18
                anchors.right: parent.right
                anchors.rightMargin: 18
                elide: Text.ElideRight
                horizontalAlignment: Text.AlignLeft
                text: user.name ? user.name : ''
                font.bold: true
                color: theme.inverted ? "#000000" : "#ffffff"
                /*color: {
                    if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                       if (theme.inverted)
                           return "black";
                       else
                           return "white";
                   } else {
                       return "black"
                   }
                }*/
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
            }

            Label {
                id: lblName
                /*anchors.top: parent.top
                anchors.left: iconArea.right
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12
                elide: Text.ElideRight
                horizontalAlignment: Text.AlignRight*/
                anchors.top: userNameFrame.top
                anchors.topMargin: userNameFrame.height/2 - lblNameShadow.height/2
                anchors.left: iconArea.right
                anchors.leftMargin: 18
                anchors.right: parent.right
                anchors.rightMargin: 18
                elide: Text.ElideRight
                horizontalAlignment: Text.AlignLeft
                text: user.name ? user.name : ''
                font.bold: true
                color: theme.inverted ? "#ffffff" : "#000000"
                /*color: {
                    if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                        if (theme.inverted)
                            return "white";
                        else
                            return "black";
                    } else {
                        return "white"
                    }
                }*/
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
            }
            
            Rectangle {
                id: userBioFrame
                //anchors.top: userUrlFrame.bottom
                anchors.top: userNameFrame.bottom
                //anchors.topMargin: userNameFrame.height
                height: (user.location.length > 0) ? userDescription.height + 14 : 0
                width: parent.width
                color: "transparent"
                /*gradient: Gradient {
                    GradientStop {
                        color: "#393939"
                        position: 0
                    }
                    GradientStop {
                        color: "#252525"
                        position: 1
                    }
                }
                Rectangle {
                    anchors.top: parent.top
                    height: 1
                    width: parent.width
                    color: "#000000"
                }
                Rectangle {
                    anchors.top: parent.top
                    anchors.topMargin: 1
                    height: 1
                    width: parent.width
                    color: "#494949"
                }*/

                Label {
                    id: userDescriptionShadow
                    text: user.description.replace(/\r/g, '')
                    elide: Text.ElideRight
                    horizontalAlignment: Text.AlignLeft
                    anchors.top: parent.top
                    anchors.topMargin: 7
                    anchors.left: parent.left
                    anchors.leftMargin: 18
                    anchors.right: parent.right
                    anchors.rightMargin: 18
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    width: parent.width
                    font.pixelSize: 24
                    maximumLineCount: (screen.currentOrientation === Screen.Landscape) ? 2 : 4;
                    lineHeightMode: Text.FixedHeight
                    lineHeight: font.pixelSize * 1.3
                    color: theme.inverted ? "#000000" : "#ffffff"
                    /*color: {
                        if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                            if (theme.inverted)
                                return "black";
                            else
                                return "white";
                        } else {
                            return "black";
                        }
                    }*/
                    visible: (user.description.length > 0)
                }
                Label {
                    id: userDescription
                    text: user.description.replace(/\r/g, '')
                    elide: Text.ElideRight
                    horizontalAlignment: Text.AlignLeft
                    anchors.top: parent.top
                    anchors.topMargin: 6
                    anchors.left: parent.left
                    anchors.leftMargin: 18
                    anchors.right: parent.right
                    anchors.rightMargin: 18
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    width: parent.width
                    font.pixelSize: 24
                    maximumLineCount: (screen.currentOrientation === Screen.Landscape) ? 2 : 4;
                    lineHeightMode: Text.FixedHeight
                    lineHeight: font.pixelSize * 1.3
                    color: theme.inverted ? "#ffffff" : "#000000"
                    /*color: {
                        if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                            if (theme.inverted)
                                return "white";
                            else
                                return "black";
                        } else {
                            return "white"
                        }
                    }*/
                    visible: (user.description.length > 0)
                }
            }

            Rectangle {
                id: frameContactInfo
                anchors.top: userBioFrame.bottom
                anchors.bottom: userUrlFrame.bottom
                anchors.bottomMargin: -12
                width: parent.width
                gradient: Gradient {
                    GradientStop {
                        color: theme.inverted ? "#393939" : "#c6c6c6"
                        position: 0
                    }
                    GradientStop {
                        color: theme.inverted ? "#252525" : "#dadada"
                        position: 1
                    }
                }
                Rectangle {
                    anchors.top: parent.top
                    height: 1
                    width: parent.width
                    color: theme.inverted ? "#000000" : "#ffffff"
                }
                Rectangle {
                    anchors.top: parent.top
                    anchors.topMargin: 1
                    height: 1
                    width: parent.width
                    color: theme.inverted ? "#494949" : "#b6b6b6"
                }
            }

            Rectangle {
                id: userLocationFrame
                anchors.top: userBioFrame.bottom
                visible: false
                height: (user.location.length > 0) ? 40 : 0
                width: parent.width
                color: "transparent"
                /*gradient: Gradient {
                    GradientStop {
                        color: "#393939"
                        position: 0
                    }
                    GradientStop {
                        color: "#252525"
                        position: 1
                    }
                }
                Rectangle {
                    anchors.top: parent.top
                    height: 1
                    width: parent.width
                    color: "#000000"
                }
                Rectangle {
                    anchors.top: parent.top
                    anchors.topMargin: 1
                    height: 1
                    width: parent.width
                    color: "#494949"
                }*/
            }

            Label {
                id: userLocationShadow
                text: user.location
                color: theme.inverted ? "#000000" : "#ffffff"
                /*color: {
                    if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                        if (theme.inverted)
                            return "black";
                        else
                            return "white";
                    } else {
                        return "black"
                    }
                }*/
                elide: Text.ElideRight
                /*horizontalAlignment: Text.AlignRight
                anchors.top: lblName.bottom
                anchors.topMargin: 1
                anchors.left: iconArea.right
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12*/
                horizontalAlignment: Text.AlignLeft
                anchors.top: userLocationFrame.top
                anchors.topMargin: userLocationFrame.height/2 - userLocationShadow.height/2 + 6
                anchors.left: parent.left
                anchors.leftMargin: 18
                anchors.right: parent.right
                anchors.rightMargin: 18
                wrapMode: Text.WordWrap
                font.pixelSize: constants.fontDefault
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.3
                visible: (user.location.length > 0)
            }

            Label {
                id: userLocation
                text: user.location
                color: theme.inverted ? "#ffffff" : "#000000"
                /*color: {
                    if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                        if (theme.inverted)
                            return "white";
                        else
                            return "black";
                    } else {
                        return "white"
                    }
                }*/
                elide: Text.ElideRight
                /*horizontalAlignment: Text.AlignRight
                anchors.top: lblName.bottom
                anchors.left: iconArea.right
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12*/
                horizontalAlignment: Text.AlignLeft
                anchors.top: userLocationFrame.top
                anchors.topMargin: userLocationFrame.height/2 - userLocationShadow.height/2 + 5
                anchors.left: parent.left
                anchors.leftMargin: 18
                anchors.right: parent.right
                anchors.rightMargin: 18
                wrapMode: Text.WordWrap
                font.pixelSize: constants.fontDefault
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.3
                visible: (user.location.length > 0)
            }
            
            Rectangle {
                id: userUrlFrame
                anchors.top: userLocationFrame.bottom
                height: (user.url.length > 0) ? 40 : 0
                width: parent.width
                color: "transparent"
                /*gradient: Gradient {
                    GradientStop {
                        color: "#393939"
                        position: 0
                    }
                    GradientStop {
                        color: "#252525"
                        position: 1
                    }
                }
                Rectangle {
                    anchors.top: parent.top
                    height: 1
                    width: parent.width
                    color: "#000000"
                }
                Rectangle {
                    anchors.top: parent.top
                    anchors.topMargin: 1
                    height: 1
                    width: parent.width
                    color: "#494949"
                }*/
            }

            Label {
                id: userUrlShadow
                text: user.url
                color: theme.inverted ? "#000000" : "#ffffff"
                /*{
                    if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                        if (theme.inverted)
                            return "black";
                        else
                            return "white";
                    } else {
                        return "black";
                    }
                }*/
                elide: Text.ElideRight
                /*horizontalAlignment: Text.AlignRight
                anchors.top: userLocation.bottom
                anchors.topMargin: 1
                anchors.left: iconArea.right
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12*/
                horizontalAlignment: Text.AlignLeft
                anchors.top: userUrlFrame.top
                anchors.topMargin: userUrlFrame.height/2 - userUrlShadow.height/2 + 6
                anchors.left: parent.left
                anchors.leftMargin: 18
                anchors.right: parent.right
                anchors.rightMargin: 18
                font.pixelSize: 24
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.3
                visible: (user.url.length > 0)
            }

            Label {
                id: userUrl
                text: user.url
                color: theme.inverted ? "#ffffff" : "#000000"
                /*{
                    if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                        if (theme.inverted)
                            return "white";
                        else
                            return "black";
                    } else {
                        return "white"
                    }
                }*/
                elide: Text.ElideRight
                /*horizontalAlignment: Text.AlignRight
                anchors.top: userLocation.bottom
                anchors.left: iconArea.right
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12*/
                horizontalAlignment: Text.AlignLeft
                anchors.top: userUrlFrame.top
                anchors.topMargin: userUrlFrame.height/2 - userUrlShadow.height/2 + 5
                anchors.left: parent.left
                anchors.leftMargin: 18
                anchors.right: parent.right
                anchors.rightMargin: 18
                font.pixelSize: 24
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.3
                MouseArea {
                    anchors.fill: parent
                    onClicked: if (user.url.length > 0)
                                   Qt.openUrlExternally(user.url)
                }
                visible: (user.url.length > 0)
            }

            /*Label {
                id: userDescriptionShadow
                text: user.description.replace(/\r/g, '')
                elide: Text.ElideRight
                horizontalAlignment: Text.AlignRight
                //anchors.top: iconAreaFrame.bottom
                //anchors.topMargin: 7
                anchors.bottom: userArea.bottom
                anchors.bottomMargin: 8
                anchors.left: parent.left
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                width: parent.width
                font.pixelSize: 24
                maximumLineCount: (screen.currentOrientation === Screen.Landscape) ? 2 : 4;
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.3
                color: {
                    if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                        if (theme.inverted)
                            return "black";
                        else
                            return "white";
                    } else {
                        return "black";
                    }
                }
                visible: (user.description.length > 0)
            }
            Label {
                id: userDescription
                text: user.description.replace(/\r/g, '')
                elide: Text.ElideRight
                horizontalAlignment: Text.AlignRight
                //anchors.top: iconAreaFrame.bottom
                //anchors.topMargin: 6
                anchors.bottom: userArea.bottom
                anchors.bottomMargin: 9
                anchors.left: parent.left
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                width: parent.width
                font.pixelSize: 24
                maximumLineCount: (screen.currentOrientation === Screen.Landscape) ? 2 : 4;
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.3
                color: {
                    if (user.profile_banner_url == undefined || user.profile_banner_url == "") {
                        if (theme.inverted)
                            return "white";
                        else
                            return "black";
                    } else {
                        return "white"
                    }
                }
                visible: (user.description.length > 0)
            }*/
        }
    }
}
