﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import '../Components'
import '../Delegates'

Page {
    id: aboutPage

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        newtweet: false
        text: qsTr('About')
    }

    Flickable {
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        contentHeight: content.height
        clip: true
        Rectangle {
            id: content
            //anchors.fill: parent
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            height: aboutText.height + supportText.height + 25
            color: "transparent"

            Image {
                id: logo
                x: 17
                y: 17
                width: 80
                height: 80
                source: "qrc:/rocket80.png"
                MouseArea {
                    anchors.fill: parent
                    onDoubleClicked: {
                        // TODO: Add easter egg :)
                    }
                }
            }

            Column {
                id: aboutText
                anchors.left: logo.right
                anchors.leftMargin: 17
                anchors.top: parent.top
                anchors.topMargin: 15
                //spacing: 17
                Label {
                    text: "Rocket"
                }
                Label {
                    text: qsTr("Version: %1").arg(constants.version)
                }
                Label {
                    text: "© Webpoint Studio, 2012"
                }
            }

            Rectangle {
                id: line1
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.right: parent.right
                anchors.rightMargin: 10
                anchors.top: aboutText.bottom
                anchors.topMargin: 10
                height: 1
                color: "black"
            }

            Column {
                id: supportText
                anchors.left: parent.left
                anchors.leftMargin: 17
                anchors.top: line1.bottom
                anchors.topMargin: 10
                //spacing: 17
                Label {
                    text: "Homepage:"
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="http://webpointstudio.ru/rocket/">http://webpointstudio.ru/rocket/</a>').arg(constants.linkStyle)
                    onLinkActivated: {
                        Qt.openUrlExternally(link);
                    }
                }
                Label {
                    text: "Support e-mail:"
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="mailto:info@webpointstudio.ru?subject=Rocket">info@webpointstudio.ru</a>').arg(constants.linkStyle)
                    onLinkActivated: {
                        Qt.openUrlExternally(link);
                    }
                }
                Label {
                    text: "Twitter:"
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="@ukhamitov">@ukhamitov</a>').arg(constants.linkStyle)
                    TwitUser {
                        id: ukhamitov
                        screen_name: 'ukhamitov'
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: pageStack.push(userPage, {'id_str': ukhamitov.id_str})
                    }
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="@ruwebpoint">@ruwebpoint</a>').arg(constants.linkStyle)
                    TwitUser {
                        id: ruwebpoint
                        screen_name: 'ruwebpoint'
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            pageStack.push(userPage, {'id_str': ruwebpoint.id_str})
                        }
                    }
                }
                Label {
                    text: "Special thanks:"
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="@knobtviker">@basil_s - N900 Maemo porting</a>').arg(constants.linkStyle)
                    TwitUser {
                        id: basils
                        screen_name: 'basil_s'
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: pageStack.push(userPage, {'id_str': basils.id_str})
                    }
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="@task_jp">@task_jp - QNeptunea project</a>').arg(constants.linkStyle)
                    TwitUser {
                        id: task_jp
                        screen_name: 'task_jp'
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: pageStack.push(userPage, {'id_str': task_jp.id_str})
                    }
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="@rnazarov">@rnazarov - TitanIM project</a>').arg(constants.linkStyle)
                    TwitUser {
                        id: rnazarov
                        screen_name: 'rnazarov'
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: pageStack.push(userPage, {'id_str': rnazarov.id_str})
                    }
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="@knobtviker">@knobtviker - Dropian project</a>').arg(constants.linkStyle)
                    TwitUser {
                        id: knobtviker
                        screen_name: 'knobtviker'
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: pageStack.push(userPage, {'id_str': knobtviker.id_str})
                    }
                }
                Label {
                    anchors.left: parent.left
                    anchors.leftMargin: 17
                    text: qsTr('<style type="text/css">a.link{%2}</style>%1').arg('<a class="link" href="@IlyaSkriblovsky">@IlyaSkriblovsky - MeeBible project</a>').arg(constants.linkStyle)
                    TwitUser {
                        id: ilyaSkriblovsky
                        screen_name: 'IlyaSkriblovsky'
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: pageStack.push(userPage, {'id_str': ilyaSkriblovsky.id_str})
                    }
                }
            }
        }
    }

    tools: ToolBarLayout {
        id: toolBar
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: {
                pageStack.pop()
            }
        }
    }
}
