﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import '../Views'
import '../Delegates'
import '../Components'

Page {
    id: accountPage

    property bool selectingMedia: false

    onStatusChanged: {
        if (accountPage.status === PageStatus.Active) {
            if (selectingMedia) {
                if (mediaSelected !== undefined) {
                    profile_image.source = mediaSelected
                    mediaSelected = undefined
                }
                selectingMedia = false
            } else if (!retweet)
                name.forceActiveFocus()
        }
    }

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
    }

    UpdateProfile {
        id: updateProfile
        name: name.text
        url: url.text
        location: location.text
        description: description.text

        onLoadingChanged: if (!loading) pageStack.pop()
    }

    Settings {
        id: settings
    }

    Flickable {
        id: container
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: statusBar.top

        contentHeight: profilePane.height
        clip: true

        Column {
            anchors.top: parent.top
            anchors.topMargin: 17
            anchors.left: parent.left
			anchors.leftMargin: 17
            id: profilePane
            width: parent.width
            spacing: 4

            Row {
                spacing: 4
                Label { text: 'Picture:' }

                Image {
                    id: profile_image
                    width: constants.listViewIconSize
                    height: constants.listViewIconSize
                    source: verifyCredentials.profile_image_url.replace("_normal", "_bigger");//'http://api.twitter.com/1/users/profile_image?screen_name='.concat(verifyCredentials.screen_name).concat('&size=bigger') //verifyCredentials.profile_image_url
                    smooth: true
                    MouseArea {
                        anchors.fill: parent
                        enabled: !header.busy
                        onClicked: {
                            accountPage.selectingMedia = true
                            mediaSelected = undefined
                            pageStack.push(selectMediaPage)
                        }
                    }
                }
            }
            Label {
				text: 'Name:'
			}
            TextField {
                id: name
                width: parent.width - 34
                enabled: !header.busy
                text: verifyCredentials.name
                maximumLength: 20
                platformStyle: TextFieldStyle { textFont.pixelSize: constants.fontDefault }
                platformSipAttributes: SipAttributes {
                    actionKeyLabel: 'Next'
                }
                Keys.onReturnPressed: location.forceActiveFocus()
            }

            Label {
				text: 'Location:'
			}
            TextField {
                id: location
                width: parent.width - 34
                enabled: !header.busy
                text: verifyCredentials.location
                maximumLength: 30
                platformStyle: TextFieldStyle { textFont.pixelSize: constants.fontDefault }
                platformSipAttributes: SipAttributes {
                    actionKeyLabel: 'Next'
                }
                Keys.onReturnPressed: url.forceActiveFocus()
            }

            Label {
				text: 'Web:'
			}
            TextField {
                id: url
                width: parent.width - 34
                enabled: !header.busy
                text: verifyCredentials.url
                maximumLength: 100
                platformStyle: TextFieldStyle { textFont.pixelSize: constants.fontDefault }
                platformSipAttributes: SipAttributes {
                    actionKeyLabel: 'Next'
                }
                Keys.onReturnPressed: description.forceActiveFocus();
            }

            Label {
				text: 'Bio:'
			}
            TextArea {
                id: description
                width: parent.width - 34
                enabled: !header.busy
                text: verifyCredentials.description
                platformStyle: TextAreaStyle { textFont.pixelSize: constants.fontDefault }
            }
            Button {
                id: profileUpdate
                width: parent.width - 34
                enabled: !verifyCredentials.loading && !updateProfile.loading
                text: qsTr('Update')
                platformStyle: ButtonStyle { fontPixelSize: constants.fontDefault }
                onClicked: updateProfile.exec()
            }
            Button {
                id: btnSignOut
                width: parent.width - 34
                platformStyle: ButtonStyle { fontPixelSize: constants.fontDefault }
                //iconSource: 'image://theme/icon-m-toolbar-update'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Sign out')
                onClicked: {
                    oauth.unauthorize();
                    thumbnailCacher.clearAll();
                    //oauth.request_token();
                    pageStack.pop(mainPage)
                }
            }
        }
        Column {
            id: settingsPane
            width: parent.width
            spacing: 4

            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'always_use_https'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.always_use_https
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'discoverable_by_email'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.discoverable_by_email
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'geo_enabled'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.geo_enabled
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'language'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.language
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'protected'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings._protected
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'screen_name'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.screen_name
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'show_all_inline_media'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.show_all_inline_media
            }

            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'sleep_time'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.sleep_time.enabled
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.sleep_time.start_time
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.sleep_time.end_type
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'time_zone'
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.time_zone.name
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: settings.time_zone.utc_offset
            }
            Label {
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                text: 'trend_location' + settings.trend_location.length
            }

            Repeater {
                model: settings.trend_location
                Column {
                    width: settingsPane.width
                    spacing: 4

                    Label {
                        platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
//                        text: settings.trend_location[index].country
                        text: modelData.country
                    }
                    Label {
                        platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
//                        text: settings.trend_location[index].countryCode
                        text: modelData.countryCode
                    }
                    Label {
                        platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
//                        text: settings.trend_location[index].name
                        text: modelData.name
                    }
                    Label {
                        platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
//                        text: settings.trend_location[index].parentid
                        text: modelData.parentid
                    }
                    Label {
                        platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
//                        text: settings.trend_location[index].placeType.code
                        text: modelData.placeType.code
                    }
                    Label {
                        platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
//                        text: settings.trend_location[index].placeType.name
                        text: modelData.placeType.name
                    }
                    Label {
                        platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
//                        text: settings.trend_location[index].url
                        text: modelData.url
                    }
                    Label {
                        platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
//                        text: settings.trend_location[index].woeid
                        text: modelData.woeid
                    }
                }
            }
        }
    }

    Menu {
        id: menu
        visualParent: container
        MenuLayout {
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-update'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Sign out')
                onClicked: {
                    oauth.unauthorize();
                    thumbnailCacher.clearAll();
                    //oauth.request_token();
                    pageStack.pop(mainPage)
                }
            }
        }
    }

    ToolBar {
        id: statusBar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        tools: ToolBarLayout {
                ToolIcon {
                    platformIconId: "toolbar-back"
                    enabled: pageStack && pageStack.depth > 1
                    opacity: enabled ? 1.0 : 0.5
                    onClicked: {
                        pageStack.pop()
                    }
                }

                /*ToolIcon {
                    platformIconId: "toolbar-home"
                    enabled: pageStack && pageStack.depth > 1
                    opacity: enabled ? 1.0 : 0.5
                    onClicked: pageStack.pop(mainPage)
                }

                ToolSpacer {}*/

                ToolIcon {
                    id: showProfile
                    platformIconId: "toolbar-contact"
                    enabled: !header.busy
                    opacity: enabled ? 1.0 : 0.5
					visible: false
                    onClicked: accountPage.state = 'profile'
                }

                ToolIcon {
                    id: showSettings
                    platformIconId: "toolbar-settings"
                    enabled: !header.busy
                    opacity: enabled ? 1.0 : 0.5
                    onClicked: accountPage.state = 'settings'
					visible: false
                }

                ToolSpacer {}

                ToolIcon {
                    platformIconId: "toolbar-view-menu"
                    onClicked: {
                        if (menu.status == DialogStatus.Closed)
                            menu.open()
                        else
                            menu.close()
                    }
                }
            }
    }

    state: 'profile'
    states: [
        State {
            name: 'profile'
            PropertyChanges {
                target: container
                contentHeight: profilePane.height
            }
            PropertyChanges {
                target: settingsPane
                opacity: 0
            }
            PropertyChanges {
                target: showProfile
                enabled: false
            }
        },
        State {
            name: 'settings'
            PropertyChanges {
                target: container
                contentHeight: settingsPane.height
            }
            PropertyChanges {
                target: profilePane
                opacity: 0
            }
            PropertyChanges {
                target: showSettings
                enabled: false
            }
        }

    ]
    transitions: [
        Transition {
            from: "profile"
            to: "settings"
            NumberAnimation { properties: 'opacity' }
        },
        Transition {
            from: "settings"
            to: "profile"
            NumberAnimation { properties: 'opacity' }
        }
    ]
}
