/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import '../Components'

Page {
    id: root

    property alias url: preview.source

    Item {
        id: rootZoomableImage

        width: parent.width
        height: parent.height

        Rectangle {
            anchors.fill: parent
            color: "black"
        }

        Flickable {
             id: flickable
             clip: true
             width:  parent.width
             height: parent.height
             contentWidth: imageContainer.width
             contentHeight: imageContainer.height
             onHeightChanged: photo.calculateSize()

             Item {
                 id: imageContainer
                 width: Math.max(photo.width * photo.scale, flickable.width)
                 height: Math.max(photo.height * photo.scale, flickable.height)

                 AnimatedImage {
                     id: photo
                     property real prevScale
                     anchors.centerIn: parent
                     smooth: !flickable.movingVertically
                     /*sourceSize.width: rootZoomableImage.photoWidth
                     sourceSize.height:rootZoomableImage.photoHeight*/
                     fillMode: Image.PreserveAspectFit

                     function calculateSize()
                     {
                         scale = Math.min(flickable.width / width, flickable.height / height) * 0.98;
                         pinchArea.minScale = scale;
                         prevScale = Math.min(scale, 1);
                     }

                     onStatusChanged: {
                         if (status == Image.Loading) {
                            indicator.visible = true;
                         } else
                         if (status == Image.Error ){
                             console.log("Error while loading an image ");
                             indicator.visible = false;
                         }
                         else
                         if (status == Image.Ready) {
                             indicator.visible = false;
                             calculateSize();
                         }
                     }

                     onScaleChanged: {

                         if ((width * scale) > flickable.width) {
                             var xoff = (flickable.width / 2 + flickable.contentX) * scale / prevScale;
                             flickable.contentX = xoff - flickable.width / 2;
                         }
                         if ((height * scale) > flickable.height) {
                             var yoff = (flickable.height / 2 + flickable.contentY) * scale / prevScale;
                             flickable.contentY = yoff - flickable.height / 2;
                         }

                         prevScale = scale;
                     }
                 }
             }
        }

        BusyIndicator {
            id: indicator
            z: 1005
            running: photo.status != Image.Ready
            anchors.centerIn: parent
            platformStyle: BusyIndicatorStyle {
                spinnerFrames: "image://theme/spinnerinverted";
                size: "large";
            }
            visible: running
        }

        Label {
            id: lblProgress
            anchors.top: indicator.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            text: qsTr("Loading...") + " " + progress + "%"
            visible: indicator.visible
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            pageStack.pop();
        }
        visible: preview.status != Image.Ready
    }
}
