﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
//import com.nokia.meego 1.0
import TwitterCore 1.0
import TwitterCore.extra 1.0
//import Qt.labs.shaders 1.0
import '../Components'
import '../Views'
import Rocket 1.0

AbstractPage {
    id: root

    property bool active: false
    property string __maxReadIdStr: settings.readData('HomePage/maxReadIdStr', '')
    property variant topData: model.get(view.topItemIndex)
    onTopDataChanged: refresh.toBeRefreshed = true
    property int unreadCount: 0

    property string cacheUrl

    property string cacheSource: "";

    Timer {
        id: refresh
        property bool toBeRefreshed: true
        running: refresh.toBeRefreshed && platformWindow.visible && !homeTimeline.loading
        interval: 250
        repeat: false
        onTriggered: {
            if (view.count > 0) {
                var id_str = model.get(Math.max(0, view.topItemIndex)).id_str
                if (root.__maxReadIdStr.length < id_str.length) {
                    root.__maxReadIdStr = id_str
                } else if (root.__maxReadIdStr.length == id_str.length && root.__maxReadIdStr < id_str) {
                    root.__maxReadIdStr = id_str
                } else if (view.atYBeginning && root.__maxReadIdStr.length == 0) {
                    root.__maxReadIdStr = id_str
                }
                root.unreadCount = model.indexOf(root.__maxReadIdStr)
            }
            refresh.toBeRefreshed = false
        }
    }

    function moveToTop() {
        if (root.topData.id_str === root.__maxReadIdStr || root.unreadCount == 0)
            view.positionViewAtBeginning()
        else
            view.positionViewAtIndex(root.unreadCount - 1, ListView.Beginning)
    }

    property bool loadedUntilLastPos: false
    function updateLoadedUntilLastPos() {
        var loadedUntilLastPos = true
        for (var i = 0; i < model.childObjects.length; i++) {
            if (!model.childObjects[i].streaming && model.childObjects[i].loadingUntilLastPos) {
                loadedUntilLastPos = false
                break
            }
        }
        root.loadedUntilLastPos = loadedUntilLastPos
    }

    Timer {
        id: positionViewAtBeginning
        running: root.loadedUntilLastPos
        repeat: false
        interval: 500
        onTriggered: {
            view.positionViewAtBeginning()
            for (var i = 0; i < model.childObjects.length; i++) {
                if (!model.childObjects[i].streaming)
                    model.childObjects[i].loadUntilLatest()
            }
        }
    }

    StateGroup {
        states: [
            State {
                name: 'fake visible'
                when: root.parent.visible && !root.loadedUntilLastPos
                PropertyChanges {
                    target: root
                    visible: true
                    opacity: 1.0
                }
            },
            State {
                name: "page stack is available"
                when: typeof pageStack === 'object'
                PropertyChanges {
                    target: refresh
                    running: refresh.toBeRefreshed && platformWindow.visible && !homeTimeline.loading && pageStack.depth == 1
                }
            }
        ]
    }

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        busy: homeTimeline.loading
        text: qsTr("Timeline")
        onClicked: view.positionViewAtBeginning()
    }

    Image {
        id: cacheImage
        visible: false;

        function loadImage() {
            if (source == "") {
                cacheImage.source = thumbnailCacher.get(root.cacheSource) || (networkConfigurationManager.online ? root.cacheSource : root.cacheSource)
            }
        }

        onStatusChanged: {
            if(status == Image.Ready){
                if(source == root.cacheSource)
                    thumbnailCacher.cache(root.cacheSource, cacheImage)
            }
        }

        Component.onCompleted: {
            cacheImage.loadImage();
        }
    }

    HomeTimelineModel {
        id: eventFeedModel

        count: 100
        sortKey: 'id_str'
        since_id: settings.readData('EventFeed/maxReadIdStr', '')// == '' ? model.get(0).id_str : model.get(0).id_str //settings.readData('EventFeed/maxReadIdStr', '');

        property int lastSize: 0

        onLoadingChanged: {
            if (loading) {
                //                console.debug('since_id', since_id)
            } else {
                if (eventFeedModel.size > 0 && eventFeedModel.get(0).id_str !== settings.readData('EventFeed/maxReadIdStr', '') && constants.publishToEventFeed) {
                    for(var i = 0; i < eventFeedModel.size; i++)
                    {
                        var component = eventFeed.createObject(window);
                        var item = eventFeedModel.get(i);
                        cacheSource = item.user.profile_image_url;//'http://api.twitter.com/1/users/profile_image?screen_name='.concat(item.user.screen_name).concat('&size=normal');
                        cacheImage.loadImage();
                        component.icon = thumbnailCacher.getForFeed(cacheSource);
                        component.title = item.user.screen_name;
                        component.body = item.plain_text;
                        component.timestamp = new Date(item.created_at);
                        component.action = "rocket://status/"+item.id_str;
                        component.publish()
                    }
                    settings.saveData('EventFeed/maxReadIdStr', eventFeedModel.get(0).id_str)
                }
            }
        }
    }

    StatusListView {
        id: view
        anchors { top: header.bottom; left: parent.left; right: parent.right; bottom: parent.bottom }
        loading: model.loading
        active: (root.active && !homeTimeline.loading) || !root.loadedUntilLastPos
        visible: root.visible
        //sect:
        model: UnionModel {
            id: model
            UserStreamModel {
                id: userStream
                enabled: !(homeTimeline.loading && homeTimeline.pushOrder != HomeTimelineModel.PushOlderToNewer) && !positionViewAtBeginning.running && test.online// && constants.streaming
                //onFollowedBy: infoBanners.followedBy(status)
                //onFavorited: infoBanners.favorited(status)
                onFiltering: {
                    if (value.user.id_str !== oauth.user_id && window.friends.length > 0 && window.friends.indexOf(value.user.id_str) < 0) userStream.filter()
                    if (window.filter(value)) userStream.filter()
                }
                //onFriendsChanged: window.friends = friends
            }
            HomeTimelineModel {
                id: homeTimeline
                count: 50
                pushOrder: HomeTimelineModel.PushAtOnce
                sortKey: 'id_str'
                max_id: constants.restoringLastPositionDisabled ? '' : root.__maxReadIdStr
                onFiltering: if (window.filter(value)) homeTimeline.filter();
                property bool loadingUntilLastPos: true
                property bool loadingUntilLatest: false
                property int lastSize: 0

                function loadUntilLatest() {
                    //console.log("loadUntilLatest()");
                    //                    var component = eventFeed.createObject(window)
                    //                    var item = model.get(i)
                    //                    component.icon = 'http://api.twitter.com/1/users/profile_image?screen_name='.concat(item.user.screen_name).concat('&size=normal');
                    //                    component.title = item.user.screen_name;
                    //                    component.body = item.plain_text;
                    //                    component.publish()
                    homeTimeline.pushOrder = HomeTimelineModel.PushOlderToNewer
                    loadingUntilLatest = true
                    lastSize = size
                    since_id = size > 0 ? model.get(0).id_str : ''
                    max_id = ''
                    count = 200
                    //page = 1
                    //if (view.atYBeginning)
                        view.contentY++
                    reload()
                }

                onLoadingChanged: {
                    /*console.log("maxRead: "+root.__maxReadIdStr + " | " + model.get(0).id_str);
                    var maxPublished = root.__maxReadIdStr;
                    var topReaded = model.get(0).id_str;
                    if (maxPublished < topReaded)
                    {
                        for (var i = 0; i < model.indexOf(maxPublished); i++)
                        {
                            var item = model.get(i)
                            console.log("For 1: " + item.user.screen_name + "\n" + item.plain_text);
                            var component = eventFeed.createObject(window)
                            var item = model.get(i)
                            cacheSource = 'http://api.twitter.com/1/users/profile_image?screen_name='.concat(item.user.screen_name).concat('&size=normal');
                            cacheImage.loadImage();
                            component.icon = thumbnailCacher.getForFeed(cacheSource);
                            component.title = item.user.screen_name;
                            component.body = item.plain_text;
                            component.timestamp = new Date(item.created_at);
                            component.action = "rocket://status/"+item.id_str;
                            component.publish()
                        }
                        maxPublished = model.get(0).id_str;
                        settings.saveData('EventFeed/maxReadIdStr', model.get(0).id_str)
                        settings.saveData('HomePage/maxReadIdStr', model.get(0).id_str)
                    }*/
                    if (loading) {
                        //console.debug('loading 1:', max_id, since_id, size, lastSize)
                    } else {
                        //console.debug('loading 2:', model.get(0).id_str, since_id, size, lastSize)
                        if (loadingUntilLastPos) {
                            loadingUntilLastPos = false
                            root.updateLoadedUntilLastPos()
                        } else if (loadingUntilLatest) {
                            if (lastSize == size) {
                                view.contentY--
                                loadingUntilLatest = false
                            } else {
                                lastSize = size
                                //page++
                                reload()
                            }
                        }
                    }
                }
            }

            onSizeChanged: refresh.toBeRefreshed = true
        }
        onTopItemIndexChanged: refresh.toBeRefreshed = true

        onReload: {
            if (test.online) {
                if (!homeTimeline.loading) {
                    homeTimeline.loadUntilLatest()
                }

                if (!userStream.loading) {
                    userStream.reload()
                }
            } else {
                test.exec()
            }
        }
        onMore: {
            if (!homeTimeline.loading) {
                homeTimeline.pushOrder = HomeTimelineModel.PushNewerToOlder
                homeTimeline.max_id = homeTimeline.size == 0 ? '' : homeTimeline.get(homeTimeline.size - 1).id_str
                homeTimeline.count = 50
                homeTimeline.since_id = ''
                homeTimeline.reload()
            }
        }

        onShowDetail: if (state != 'loading') pageStack.push(statusPage, {'id_str': detail.id_str})
        onLinkActivated: {
            if (state != 'loading') {
                root.openLink(link)
            }
        }

        /*states: [
            State {
                name: 'loading'
                when: homeTimeline.loading || positionViewAtBeginning.running
                PropertyChanges {
                    target: view
                    interactive: false
                }
            }
        ]*/
    }

    /*Timer {
        running: !constants.streaming && interval > 0 && test.online
        interval: constants.updateInterval * 60 * 1000
        repeat: true
        onTriggered: {
            for (var i = 0; i < model.childObjects.length; i++) {
                if (!model.childObjects[i].streaming)
                    model.childObjects[i].loadUntilLatest()
            }
        }
    }*/

    /*TweetMarker {
        id: tweetMarker
        verifyCredentialsFormat: 'json'
        onDone: {
            var json = JSON.parse(result)
            if (ok && typeof json.url !== 'undefined') {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += json.url
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }*/

    /*Timer {
        running: interval > 0 && test.online && constants.publishToEventFeed
        interval: 0//20 * 60 * 1000
        repeat: true
        onTriggered: {
            if (!eventFeedModel.loading && eventFeedModel.max_id != settings.readData('EventFeed/maxReadIdStr', ''))
            {
                eventFeedModel.pushOrder = HomeTimelineModel.PushOlderToNewer
                eventFeedModel.lastSize = eventFeedModel.size
                eventFeedModel.since_id = eventFeedModel.size > 0 ? eventFeedModel.get(0).id_str : ''
                eventFeedModel.max_id = '';
                eventFeedModel.page = 1;
                eventFeedModel.reload();
            }
        }
    }*/

    Connections {
        target: oauth
        onStateChanged: {
            if (oauth.state === OAuth.Unauthorized) {
                /*var parameters = {
                    'media': tweetPage.media[0]
                }
                tweetMarker.setMarker(parameters);*/
                settings.saveData('HomePage/maxReadIdStr', '')
            }
        }
    }

    Component.onDestruction: {
        if (oauth.state === OAuth.Authorized) {
            var parameters = {
                "timeline": {
                    "id": root.__maxReadIdStr.length > 0 ? root.__maxReadIdStr : settings.readData('HomePage/maxReadIdStr', '')
                }
            }
            tweetMarker.setMarker(parameters, verifyCredentials.screen_name);
            settings.saveData('HomePage/maxReadIdStr', root.__maxReadIdStr);
        }
    }

    Connections {
        target: test
        onOnlineChanged: {
            if (test.online) {
                if (!homeTimeline.loading) {
                    homeTimeline.loadUntilLatest()
                }
            }
        }
    }
}
