﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import '../Components'

Page {
    id: root

    property alias list_id: list.id_str

    List { id: list }

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top

        busy: list.loading
    }

    Column {
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: statusBar.top
        anchors.margins: 17
        spacing: 17

        Label { text: qsTr('Name') }
        TextField {
            id: name
            anchors.margins: 17
            text: list.name ? list.name : ''
            width: parent.width
        }
        Label { text: qsTr('Description') }
        TextArea {
            id: description
            anchors.margins: 17
            text: list.description ? list.description : ''
            width: parent.width
        }
        Row {
            anchors.horizontalCenter: parent.horizontalCenter
            spacing: 17
            RadioButton {
                id: modePublic
                text: qsTr('Public')
                checked: list.mode ? list.mode == 'public' : true
            }
            RadioButton {
                id: modePrivate
                text: qsTr('Private')
                checked: list.mode ? list.mode == 'private' : false
            }
        }
    }

    Menu {
        id: menu
        visualParent: root.pageStack
        MenuLayout {
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-add'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Create')
                enabled: false
            }
        }
    }

    ToolBar {
        id: statusBar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        tools: ToolBarLayout {
            id: toolBarLayout
            visible: true
            ToolIcon {
                platformIconId: "toolbar-back"
                onClicked: pageStack.pop()
            }
            /*ToolIcon {
                platformIconId: "toolbar-home"
                onClicked: pageStack.pop(mainPage)
            }
            ToolSpacer {columns: 3}*/
            ToolIcon {
                platformIconId: 'toolbar-done'
                onClicked: {
                    if (list.id_str.length == 0) {
                        list.createList({'name': name.text, 'description': description.text, 'mode': modePublic.checked ? 'public' : 'private' })
                    } else {
                        list.updateList({'list_id': list.id_str, 'name': name.text, 'description': description.text, 'mode': modePublic.checked ? 'public' : 'private' })
                    }
                }
            }
        }
    }
}
