﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import '../Views'
import '../Components'

Page {
    id: root

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
    }

    Settings {
        id: settings
        onLoadingChanged: {
            if (!loading) {
                if (settings.trend_location.length > 0) {
                    trendsModel.woeid = settings.trend_location[0].woeid
                    console.debug(settings.trend_location[0].woeid)
                }
            }
        }
    }

    TrendListView {
        id: trendsView
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: statusBar.top

        header: TextField {
            id: search
            width: ListView.view.width
            placeholderText: qsTr('Search')
            platformStyle: TextFieldStyle { textFont.pixelSize: constants.fontDefault }
            platformSipAttributes: SipAttributes {
                actionKeyLabel: 'Search'
                actionKeyEnabled: search.text.length > 0
            }
            Keys.onReturnPressed: {
                showSuggestions.forceActiveFocus()
                pageStack.push(searchPage, {query: search.text})
            }
        }

        model: TrendsAvailableModel { id: trendsModel }
        onShowDetail: pageStack.push(searchPage, {query: detail.name})
    }

    SlugListView {
        id: suggestionsView
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: statusBar.top

        header: TextField {
            id: searchUser
            width: ListView.view.width
            placeholderText: qsTr('People Search')
            platformStyle: TextFieldStyle { textFont.pixelSize: constants.fontDefault }
            platformSipAttributes: SipAttributes {
                actionKeyLabel: 'Search'
                actionKeyEnabled: searchUser.text.length > 0
            }
            Keys.onReturnPressed: {
                showTrends.forceActiveFocus()
                pageStack.push(searchUsersPage, {q: searchUser.text})
            }
        }

        model: SlugsModel { id: slugsModel; lang: settings.language }
        onShowDetail: pageStack.push(suggestionsPage, {slug: detail, lang: settings.language})
    }

    ToolBar {
        id: statusBar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        tools: ToolBarLayout {
                ToolIcon {
                    platformIconId: "toolbar-back"
                    enabled: pageStack && pageStack.depth > 1
                    opacity: enabled ? 1.0 : 0.5
                    onClicked: {
                        pageStack.pop()
                    }
                }

                /*ToolIcon {
                    platformIconId: "toolbar-home"
                    enabled: pageStack && pageStack.depth > 1
                    opacity: enabled ? 1.0 : 0.5
                    onClicked: pageStack.pop(mainPage)
                }

                ToolSpacer {}*/

                /*ToolIcon {
                    id: showTrends
                    platformIconId: "toolbar-list"
                    opacity: enabled ? 1.0 : 0.5
                    onClicked: root.state = "trends"
                }
                ToolIcon {
                    id: showSuggestions
                    platformIconId: "toolbar-people"
                    opacity: enabled ? 1.0 : 0.5
                    onClicked: root.state = "suggestions"
                }*/

                ToolSpacer {}
            }
    }

    state: 'trends'
    states: [
        State {
            name: "trends"
            PropertyChanges {
                target: suggestionsView
                opacity: 0
            }
            PropertyChanges {
                target: showTrends
                enabled: false
            }
            PropertyChanges {
                target: header
                //text: qsTr('Local Trends')
                busy: settings.loading || trendsModel.loading
            }
        },
        State {
            name: "suggestions"
            PropertyChanges {
                target: trendsView
                opacity: 0
            }
            PropertyChanges {
                target: showSuggestions
                enabled: false
            }
            PropertyChanges {
                target: header
                //text: qsTr('Suggestions')
                busy: slugsModel.loading
            }
        }
    ]

    transitions: [
        Transition {
            from: "suggestions"
            to: "trends"
            NumberAnimation { properties: 'opacity' }
        },
        Transition {
            from: "trends"
            to: "suggestions"
            NumberAnimation { properties: 'opacity' }
        }
    ]
}
