﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import '../Components'
import QtMobility.gallery 1.1
import Rocket 1.0

Page {
    id: root

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        newtweet: false
        text: "Images"
        busy: model.status === DocumentGalleryModel.Active
    }

    Connections {
        target: tweetPage
    }

    GridView {
        id: view
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: statusBar.top
        cellWidth: (screen.currentOrientation === Screen.Portrait) ? 160 : 170
        cellHeight: (screen.currentOrientation === Screen.Portrait) ? 160 : 170
        cacheBuffer: Math.max(width, height) * 5
        clip: true

        delegate: Image {
            anchors.leftMargin: (screen.currentOrientation === Screen.Portrait) ? 3 : 0
            width: (screen.currentOrientation === Screen.Portrait) ? 156 : 170
            height: (screen.currentOrientation === Screen.Portrait) ? 156 : 170
            source: 'image://rocket/' + url
            asynchronous: true
            clip: true
            cache: false
            fillMode: Image.PreserveAspectCrop
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    mediaSelected = url;
                    pageStack.pop();
                }
            }
        }

        model: model.ready ? model : undefined
    }

    DocumentGalleryModel {
        id: model
        property bool ready: status === DocumentGalleryModel.Idle || status === DocumentGalleryModel.Finished
        rootType: DocumentGallery.Image
        properties: ["url"]
        sortProperties: ["-lastModified"]
        filter: GalleryWildcardFilter {
            property: "fileName"
            value: "*.*"
        }
    }

    SelectionDialog {
        id: dlgService
        titleText: "Select service:"
        selectedIndex: settings.readData('ImageService/currentService', 0);
        model: ListModel {
            ListElement { name: "Twitter" }
            ListElement { name: "TwitPic" }
            ListElement { name: "Yfrog" }
            ListElement { name: "Mobypicture" }
            ListElement { name: "img.ly" }
            ListElement { name: "Posterous" }
            ListElement { name: "TwitGoo" }
            ListElement { name: "Pikchur" }
            ListElement { name: "TwitrPix" }
            ListElement { name: "Twitvid" }
            ListElement { name: "Twipple" }
            //ListElement { name: "Flickr" }
        }
        onSelectedIndexChanged: {
            settings.saveData('ImageService/currentService', dlgService.selectedIndex);
            if (dlgService.model.get(dlgService.selectedIndex).name == "Flickr")
            {
                if (!photoUploader.isFlickrAuth()) {
                    window.pageStack.push(flickrAuthPage);
        }
    }
        }
    }

    PhotoUploader {
        id: photoUploader
    }

    ToolBar {
        id: statusBar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        tools: ToolBarLayout {
            ToolIcon {
                platformIconId: "toolbar-back"
                enabled: (pageStack !== null) && pageStack.depth > 1
                opacity: enabled ? 1.0 : 0.5
                onClicked: {
                    pageStack.pop()
                }
            }

            Button {
                anchors.right: parent.right
                anchors.rightMargin: 17
                text: dlgService.model.get(dlgService.selectedIndex).name;
                onClicked: {
                    dlgService.open();
                }
            }
        }
    }
}
