﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import '../Components'

Page {
    id: root

    Configuration {
        id: configuration
    }

    DirectMessage {
        id: direct_message
        onId_strChanged: {
            if (id_str.length > 0 && root.status === PageStatus.Active) {
                pageStack.pop()
            }
        }
    }

    property variant to
    property bool first: true

    onStatusChanged: {
        if (root.status === PageStatus.Active)
            textArea.forceActiveFocus()
    }

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top

        //text: '@' + to.screen_name

        centerBusyIndicator: true;

        busy: direct_message.loading
        newtweet: false
        homeButton: false
        SheetButton {
            id: btnCancel
            z: 901
            //width: 160
            Label {
                font.pixelSize: constants.fontLSmall
                font.capitalization: Font.MixedCase
                font.weight: Font.Bold
                anchors.centerIn: parent
                text: qsTr("Cancel")
                color: "white"
            }
            anchors.left: parent.left
            anchors.verticalCenter: header.verticalCenter
            anchors.margins: 10
            onClicked: {
                textArea.platformCloseSoftwareInputPanel()
                pageStack.pop()
            }
            style: SheetButtonStyle {
                background: "image://theme/meegotouch-sheet-button-background-pressed"
                pressedBackground: "image://theme/meegotouch-sheet-button-background"
                disabledBackground: "image://theme/meegotouch-sheet-button-background-disabled"
            }
        }

        SheetButton {
            id: tweet
            z: 901
            //width: 160
            anchors.right: parent.right
            anchors.verticalCenter: header.verticalCenter
            anchors.margins: 10
            enabled: ((textArea.counter >= 0)&&(textArea.counter < 140))
            Label {
                id: lblTweet
                font.pixelSize: constants.fontLSmall
                font.capitalization: Font.MixedCase
                font.weight: Font.Bold
                horizontalAlignment: Text.AlignHCenter
                anchors.centerIn: parent
            text: qsTr('Send')
                color: "white"
            }
            onClicked: {
                direct_message.newDirectMessage({'user_id': to.id_str, 'text': textArea.text})
            }
            platformStyle: SheetButtonAccentStyle { }
        }
    }

    function count(text, max, http_length, https_length) {
        var httpPattern = new RegExp(/^http:\/\/[-_.!~*'()a-zA-Z0-9;/?:@&=+$,%#]+$/);
        var httpsPattern = new RegExp(/^https:\/\/[-_.!~*'()a-zA-Z0-9;/?:@&=+$,%#]+$/);
        var length = max - text.length
        var chunk = text.split(/[^-_.!~*'()a-zA-Z0-9;/?:@&=+$,%#]/)
        for (var i = 0; i < chunk.length; i++) {
            var http = httpPattern.exec(chunk[i]);
            if (http !== null) {
                length = length + http[0].length - http_length
            }
            var https = httpsPattern.exec(chunk[i]);
            if (https !== null) {
                length = length + https[0].length - https_length
            }
        }

        return length
    }

    TextArea {
        id: textArea
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: statusBar.top
        anchors.margins: 10
        textFormat: TextEdit.PlainText
        wrapMode: TextEdit.WordWrap
        style: textFieldStyle
        enabled: !direct_message.loading

        property string preedit: text.substring(0, cursorPosition) + platformPreedit + text.substring(cursorPosition)
        property int counter: count(preedit, 140, configuration.short_url_length, configuration.short_url_length_https)
        property int lastCursorPosition: 0

        onTextChanged: {
            if (textArea.text.match("([\.]{3})"))
            {
                if (cursorPosition !== 0)
                    lastCursorPosition = cursorPosition-2;
                textArea.text = textArea.text.replace(new RegExp("([\.]{3})",'g'), "…")
                textArea.cursorPosition = lastCursorPosition
            }
            else if (textArea.text.match("([-]{2})"))
            {
                if (cursorPosition !== 0)
                    lastCursorPosition = cursorPosition-1;
                textArea.text = textArea.text.replace(new RegExp("([-]{2})",'g'), "—")
                textArea.cursorPosition = lastCursorPosition
            }
        }

        Connections {
            target: textArea
            onActiveFocusChanged: {
                if (first) {
                    first = false
                    textArea.cursorPosition = textArea.text.length;
                }

            }
        }
        }

    TextFieldStyle {
        id: textFieldStyle
        //textColor: ui.color_text_d
		textColor: constants.tweettext_color;
        background: "transparent"
        backgroundSelected: "transparent"
        backgroundError: "transparent"
    }

    ToolBar {
        id: statusBar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        tools: ToolBarLayout {
                visible: true
            /*ToolIcon {
                    platformIconId: "toolbar-back"
                    enabled: root.pageStack.depth > 1
                    opacity: enabled ? 1.0 : 0.5
                    onClicked: {
                        textArea.platformCloseSoftwareInputPanel()
                        root.pageStack.pop()
                    }
            }*/
            Label {
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                text: textArea.counter;
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
                }
            }
    }
}
