﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import '../Components'

Page {
    id: root

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top

        text: qsTr('Settings')
    }

    SelectionDialog {
        id: imageUploadService
        titleText: "Select service:"
        selectedIndex: settings.readData('ImageService/currentService', 0);
        model: ListModel {
            ListElement { name: "Twitter" }
            ListElement { name: "TwitPic" }
            ListElement { name: "Yfrog" }
            ListElement { name: "Mobypicture" }
            ListElement { name: "img.ly" }
            ListElement { name: "Posterous" }
            ListElement { name: "TwitGoo" }
            ListElement { name: "Pikchur" }
            ListElement { name: "TwitrPix" }
            ListElement { name: "Twitvid" }
            ListElement { name: "Twipple" }
            //ListElement { name: "Flickr" }
        }
        onSelectedIndexChanged: {
            settings.saveData('ImageService/currentService', imageUploadService.selectedIndex);
        }
    }

    SelectionDialog {
        id: mapsService
        titleText: "Select service:"
        selectedIndex: settings.readData('MapsService/currentService', 0);
        model: ListModel {
            ListElement { name: "Nokia Maps" }
            ListElement { name: "Google Maps" }
        }
        onSelectedIndexChanged: {
            settings.saveData('MapsService/currentService', mapsService.selectedIndex);
        }
    }

    Flickable {
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        contentHeight: content.height+30
        clip: true

        Column {
            id: content
            anchors.top: parent.top
            anchors.topMargin: 17
            width: parent.width
            spacing: 7

            /*Button {
                text: "Add account"
                onClicked: {
                    settings.identifier = '';
                }
            }

            Button {
                text: "ukhamitov"
                onClicked: {
                    settings.identifier = 'ukhamitov';
                    //profiles.saveData('RocketProfile', 'ukhamitov')
                }
            }

            Button {
                text: "ukhamitov_test"
                onClicked: {
                    settings.identifier = 'ukhamitov_test';
                    //profiles.saveData('RocketProfile', 'ukhamitov_test')
                }
            }*/

            Label {
                text: qsTr('Font size:')
                font.bold: true
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            Slider {
                id: fontSize
                stepSize: 2
                minimumValue: 20
                maximumValue: 30
                width: parent.width
                valueIndicatorVisible: true
                valueIndicatorText: value
                value: constants.fontDefault
                onValueChanged: if (root.status === PageStatus.Active) constants.fontDefault = value
            }

            Label {
                text: qsTr('View:')
                font.bold: true
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            LabeledSwitch {
                text: qsTr('Light/Dark theme')
                checked: constants.visualTheme
                onCheckedChanged: if (root.status === PageStatus.Active) {
                    constants.visualTheme = checked
                    theme.inverted = checked
                    settings.saveData('Application/visualTheme', checked)
                }
            }

            LabeledSwitch {
                text: qsTr('Show avatar with a white substrate')
                checked: constants.showUserAvatarFrame
                onCheckedChanged: if (root.status === PageStatus.Active) {
                    constants.showUserAvatarFrame = checked
                    settings.saveData('Application/showUserAvatarFrame', checked)
                }
            }

            TumblerItem {
                anchors.left: parent.left
                anchors.leftMargin: 7
                titleText: qsTr('Picture upload service:')
                valueText: imageUploadService.model.get(imageUploadService.selectedIndex).name;
                onClicked: imageUploadService.open();
            }

            TumblerItem {
                anchors.left: parent.left
                anchors.leftMargin: 7
                titleText: qsTr('Location service:')
                valueText: mapsService.model.get(mapsService.selectedIndex).name;
                onClicked: mapsService.open();
            }

            LabeledSwitch {
                text: qsTr('Always send my location')
                checked: constants.locationAlwaysOn
                onCheckedChanged: if (root.status === PageStatus.Active) {
                    constants.locationAlwaysOn = checked
                    settings.saveData('Application/locationAlwaysOn', checked)
                }
            }

            /*Row {
                spacing: 10
                Item {
                    width: 27;
                    height: 1
                }

                Switch {
                    anchors.verticalCenter: parent.verticalCenter
                    checked: constants.showStatusBar
                    onCheckedChanged: if (root.status === PageStatus.Active) {
                        constants.showStatusBar = checked
                        if (checked)
                            window.showStatusBar = checked
                        else

                        settings.saveData('Application/showStatusBar', checked)
                    }
                }

                Label {
                    anchors.verticalCenter: parent.verticalCenter
                    text: qsTr('Show statusbar')
                    font.pixelSize: constants.fontDefault
                    MouseArea {
                        anchors.fill: parent;
                        onClicked: {
                            constants.showStatusBar = !constants.showStatusBar
                        }
                    }
                }
            }*/

            /*Row {
                spacing: 10
                Item {
                    width: 27;
                    height: 1
                }

                Switch {
                    anchors.verticalCenter: parent.verticalCenter
                    checked: constants.lockOrientation
                    onCheckedChanged: if (root.status === PageStatus.Active) {
                        constants.lockOrientation = checked
                        if (checked)
                            screen.allowedOrientations = Screen.Portrait;
                        else
                            screen.allowedOrientations = Screen.Default;
                        settings.saveData('Application/lockOrientation', checked)
                    }
                }

                Label {
                    anchors.verticalCenter: parent.verticalCenter
                    text: qsTr('Lock orientation')
                    font.pixelSize: constants.fontDefault
                    MouseArea {
                        anchors.fill: parent;
                        onClicked: {
                            constants.lockOrientation = !constants.lockOrientation
                        }
                    }
                }
            }*/

            Label {
                text: qsTr('Event feed:')
                font.bold: true
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            LabeledSwitch {
                text: qsTr('Publish to feed')
                checked: constants.publishToEventFeed
                onCheckedChanged: if (root.status === PageStatus.Active)
                    constants.publishToEventFeed = checked
            }

            /*Text {
                text: qsTr('Publish to feed:')
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            Row {
                spacing: 10
                Item {
                    width: 27;
                    height: 1
                }

                Switch {
                    anchors.verticalCenter: parent.verticalCenter
                    checked: constants.publishToEventFeed
                    onCheckedChanged: if (root.status === PageStatus.Active)
                        constants.publishToEventFeed = checked
                }

                Text {
                    anchors.verticalCenter: parent.verticalCenter
                    text: qsTr('Enabled')
                    enabled: false
                    font.pixelSize: constants.fontDefault
                    MouseArea {
                        anchors.fill: parent;
                        onClicked:
                            constants.publishToEventFeed = !constants.publishToEventFeed
                    }
                }
            }*/

            Label {
                text: qsTr('Notifications:')
                font.bold: true
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            LabeledSwitch {
                text: qsTr('Mentions')
                checked: constants.mentionsNotification
                onCheckedChanged: if (root.status === PageStatus.Active)
                    constants.mentionsNotification = checked
            }

            LabeledSwitch {
                text: qsTr('Direct Messages')
                checked: constants.messagesNotification
                onCheckedChanged: if (root.status === PageStatus.Active)
                    constants.messagesNotification = checked
            }

            Label {
                text: qsTr('Timeline:')
                font.bold: true
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            LabeledSwitch {
                text: qsTr('Show tweet time')
                checked: constants.showSinceOnTop
                onCheckedChanged: {
                    if (root.status === PageStatus.Active) {
                        constants.showSinceOnTop = checked
                        settings.saveData('Timeline/showSinceOnTop', checked)
                    }
                }
            }

            LabeledSwitch {
                text: qsTr('Show avatars')
                checked: constants.showAvatars
                onCheckedChanged:
                    if (root.status === PageStatus.Active) {
                        constants.showAvatars = checked
                        settings.saveData('Timeline/showAvatars', checked)
                    }
            }

            Label {
                text: qsTr('Read later services:')
                font.bold: true
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            Row {
                anchors.left: parent.left
                anchors.leftMargin: 17
                anchors.right: parent.right
                anchors.rightMargin: 17
                spacing: 4
                Button {
                    width: parent.width/3 - 1
                    text: qsTr("Pocket")
                    onClicked: pageStack.push(pocketPage);
                }

                Button {
                    width: parent.width/3 - 1
                    text: qsTr("Instapaper")
                    onClicked: pageStack.push(instapaperPage);
                }

                Button {
                    width: parent.width/3 - 1
                    text: qsTr("Delicious")
                    onClicked: pageStack.push(deliciousPage);
                }
            }

            Label {
                text: qsTr('Username autocomplete:')
                font.bold: true
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            LabeledSwitch {
                text: qsTr('Show avatars')
                checked: constants.showAutocompleteAvatars
                onCheckedChanged:
                    if (root.status === PageStatus.Active) {
                        constants.showAutocompleteAvatars = checked
                        settings.saveData('Autocomplete/showAutocompleteAvatars', checked)
                    }
            }

            Label {
                text: qsTr('Cache:')
                font.bold: true
                anchors.left: parent.left
                anchors.leftMargin: 17
                font.pixelSize: constants.fontDefault
            }

            Row {
                anchors.left: parent.left
                anchors.leftMargin: 17
                anchors.right: parent.right
                anchors.rightMargin: 17
                spacing: 4
                Button {
                    width: parent.width
                    text: qsTr("Clear cache")
                    onClicked: thumbnailCacher.clearAll();
                }
            }
        }
    }

    tools: ToolBarLayout {
        ToolIcon {
            platformIconId: "toolbar-back"
            enabled: (pageStack !== null) && pageStack.depth > 1
            opacity: enabled ? 1.0 : 0.5
            onClicked: {
                pageStack.pop()
            }
        }
    }
}
