﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
//import Qt.labs.shaders 1.0
import TwitterCore 1.0
import Rocket 1.0
import '../Views'
import '../Delegates'
import '../Components'
import '../Utils/ImageParser.js' as ImageParser

AbstractLinkPage {
    id: root

    property alias id_str: status.id_str

    property variant thumbnails: []
    property bool skipAfterTweeting: true

    /* В новом API выпилили
    RelatedResultsModel {
        id: relatedResults
        _id: status.retweeted_status.id_str ? status.retweeted_status.id_str : status.id_str
        sortKey: 'id_str'
        property bool done: false
        onLoadingChanged: {
            if (!loading) {
                for (var i = 0; i < relatedResults.size; i++) {
                    var tweet = relatedResults.get(i)
                    if (root.__status.id_str.length < tweet.id_str.length || (root.__status.id_str.length == tweet.id_str.length && root.__status.id_str < tweet.id_str))
                        replies.append(tweet)
                    else {
                        var found = false
                        for (var j = 0; j < conversationModel.count; j++) {
                            if (conversationModel.get(j).id_str === tweet.id_str) {
                                found = true
                                break
                            }
                        }
                        if (!found)
                            conversationModel.append(tweet)
                    }
                }
                done = true
            }
        }
    }*/

    Status {
        id: status
        id_str: root.id_str
        onId_strChanged: {
            if (id_str.length == 0 && root.status == PageStatus.Active)
                pageStack.pop()
        }

        /*onLoadingChanged: {
            if (loading) return;
            var rich_text = status.retweeted_status.rich_text ? status.retweeted_status.rich_text : status.rich_text
            var thumbnails = [];
            ImageParser.parse(rich_text, function(ret) {
                thumbnails = ret;
            });

            var media = status.retweeted_status.media ? status.retweeted_status.media : status.media
            for (var i = 0; i < media.length; i++) {
                thumbnails.push({'thumbnail': media[i], 'media': media[i]})
            }
            root.thumbnails = thumbnails
        }*/
    }

    Timer {
        running: !status.loading
        repeat: false
        interval: 100
        property bool done: false
        onTriggered: {
            if (done) return
            var rich_text = status.retweeted_status.rich_text ? status.retweeted_status.rich_text : status.rich_text
            ImageParser.parse(rich_text, function(ret) {
                var thumbnails = ret;
                root.thumbnails = thumbnails
                done = true;
            });
        }
    }

    ActivitySummary {
        id: activitySummary
    }

    Timer {
        running: true
        repeat: false
        interval: 250
        onTriggered: activitySummary._id = root.__status.id_str
    }

    property bool __retweeted: typeof status.retweeted_status.id_str !== 'undefined'
    property variant __status: __retweeted ? status.retweeted_status : status
    property variant __user: __status.user

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top

        busy: status.loading || conversationStatus.loading
        text: qsTr("Tweet")
    }

    Flickable {
        id: flickable
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        contentWidth: width
        contentHeight: detail.height
        clip: true
        contentY: delegate.y
        visible: true
        interactive: typeof root.linkMenu === 'undefined'

        Column {
            id: detail
            width: parent.width

            Repeater {
                model: ListModel {
                    id: replies
                }
                delegate: StatusDelegate {
                    width: detail.width
                    item: model
                    user: model.user
                    onClicked: pageStack.push(statusPage, {'id_str': model.id_str})
                    onLinkActivated: openLink(link)
                }
            }

            StatusDetailDelegate {
                id: delegate

                item: status.data
                user: status.data.user
                onLinkActivated: {
                    openLink(link)
                }
                onUserClicked: pageStack.push(userPage, {id_str: user.id_str})

                Behavior on height {
                    NumberAnimation {}
                }
            }
            Column {
                id: clmLocation
                anchors.left: parent.left
                anchors.leftMargin: 17
                anchors.right: parent.right
                anchors.rightMargin: 17
                spacing: constants.listViewMargins
                Label {
                    width: parent.width
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    text: status.place.full_name ? status.place.full_name : ''
                    visible: typeof status.place.full_name !== 'undefined'
                    platformStyle: LabelStyle { fontPixelSize: constants.fontSmall }
                }
                /*Label {
                    width: parent.width
                    wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                    text: status.place.country ? status.place.country : ''
                    visible: typeof status.place.country !== 'undefined'
                    platformStyle: LabelStyle { fontPixelSize: constants.fontSmall }
                }*/
                SpinnerImage {
                    id: map
                    anchors.left: parent.left
                    anchors.right: parent.right
                    property double _lat: visible && root.__status.geo.coordinates[0] ? root.__status.geo.coordinates[0] : 0.0
                    property double _long: visible && root.__status.geo.coordinates[1] ? root.__status.geo.coordinates[1] : 0.0
                    //source: "http://maps.google.com/staticmap?zoom=15&center=" + _lat + "," + _long + "&size=480x200&markers=" + _lat + "," + _long + ",red,a&saturation=-100"
                    //return "http://maps.google.com/staticmap?zoom=15&center=" + _lat + "," + _long + "&size="+map.width+"x200&markers=" + _lat + "," + _long + ",red,a&saturation=-100"
                    source: {
                        if (settings.readData('MapsService/currentService', 0) == 0)
                            return "http://m.nok.it/?app_id=yB-kcFSw0Xd3mIwNTym6&token=bAjjjWBd_e8kb84tbKfGzg&nord&c="+_lat+","+_long+"&z=15&w="+map.width+"&h=200&f=0"
                        else
                            return "http://maps.googleapis.com/maps/api/staticmap?zoom=15&center=" + _lat + "," + _long + "&size="+map.width+"x200&markers=" + _lat + "," + _long + ",red,a&saturation=-100&key=AIzaSyCxkapB1WH0U-4sk3hgrLp1DHWhMNWQ_vM&sensor=false";
                    }
                    width: 480//parent.width
                    height: 200
                    visible: typeof root.__status.geo !== 'undefined' && typeof root.__status.geo.coordinates !== 'undefined'
                    Item {
                        visible: settings.readData('MapsService/currentService', 0) != 0
                        anchors.centerIn: parent
                        height: pin.height * 2
                        Image {
                            id: pin
                            source: 'http://maps.gstatic.com/mapfiles/markers2/marker.png'
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.top: parent.top
                        }
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: pageStack.push(mapPage, {"_lat": map._lat, "_long": map._long, "mapsService": settings.readData('MapsService/currentService', 0)})
                    }
                }
                Item {
                    width: parent.width
                    height: 10
                }
            }
            Grid {
                id: images
                anchors.left: parent.left
                anchors.leftMargin: 17
                anchors.right: parent.right
                anchors.rightMargin: 17
                anchors.bottomMargin: 17
                columns: 1
                spacing: 8
                Repeater {
                    model: root.thumbnails
                    SpinnerImage {
                        width: parent.width
                        source: modelData.thumbnail
                        fillMode: Image.PreserveAspectFit
                        smooth: true;
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                pageStack.push(previewPage, {url: modelData.media})
                            }
                        }
                    }
                }
            }
            Repeater {
                id: inReplyTo
                model: ListModel {
                    id: conversationModel
                }
                delegate: StatusDelegate {
                    width: detail.width
                    item: model
                    user: model.user
                    onClicked: pageStack.push(statusPage, {id_str: model.id_str})
                    onLinkActivated: {
                        switch (true) {
                        case /^search:/.test(link):
                            pageStack.push(searchPage, {query: link.substring(7)})
                            break
                        case /^user:/.test(link):
                            pageStack.push(userPage, {id_str: link.substring(7)})
                            break
                        default:
                            ActionHandler.openUrlExternally(link)
                            break
                        }
                    }
                }
            }

            Status {
                id: conversationStatus
                id_str: root.__status.in_reply_to_status_id_str || ''

                onLoadingChanged: {
                    if (!loading) {
                        if (id_str.length > 0) {
                            conversationModel.append(data)
                            id_str = in_reply_to_status_id_str
                        }
                    }
                }
            }
        }
    }
    Connections {
        target: menu
        onStatusChanged: root.linkMenu = (menu.status == DialogStatus.Closed ? undefined : menu)
    }

    ScrollDecorator {
        flickableItem: flickable
    }

    Menu {
        id: menu
        visualParent: root.pageStack
        MenuLayout {
            /*MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-share'.concat(enabled ? "" : "-dimmed").concat(theme.inverted ? "-white" : "")
                text: qsTr('Translate')
                onClicked: {
                    translateTweet.translateTweet(__status.text);
                }
            }

            MenuItemWithIcon {
                id: favorite
                iconSource: status.favorited ? 'image://theme/icon-m-toolbar-favorite-mark'.concat(theme.inverted ? "-white" : "") : 'image://theme/icon-m-toolbar-favorite-unmark'.concat(theme.inverted ? "-white" : "")
                text: status.favorited ? qsTr('Unfavorite') : qsTr('Favorite')
                onClicked: {
                    if (status.favorited)
                        status.unfavorite()
                    else
                        status.favorite()
                }

                states: [
                    State {
                        name: "favorited"
                        when: status.favorited
                        PropertyChanges {
                            target: favorite
                            iconSource: 'image://theme/icon-m-toolbar-favorite-mark'.concat(theme.inverted ? "-white" : "")
                            text: qsTr('Unfavorite')
                        }
                    }
                ]
            }*/

            MenuItemWithIcon {
                property bool muted: window.filters.indexOf('@'.concat(root.__user.screen_name)) > -1
                iconSource: 'image://theme/icon-m-toolbar-volume'.concat(muted ? '' : '-off').concat(theme.inverted ? "-white" : "")
                text: muted ? qsTr('Unmute @%1').arg(root.__user.screen_name) : qsTr('Mute @%1').arg(root.__user.screen_name)
                onClicked: {
                    var filters = window.filters
                    if (muted) {
                        var index = filters.indexOf('@'.concat(root.__user.screen_name))
                        while (index > -1) {
                            filters.splice(index, 1)
                            index = filters.indexOf('@'.concat(root.__user.screen_name))
                        }
                    } else {
                        filters.unshift('@'.concat(root.__user.screen_name))
                    }
                    window.filters = filters
                }
            }

            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-undo'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Undo the tweet')
                visible: status.user.id_str === oauth.user_id
                onClicked: {
                    pageStack.push(tweetPage, {'statusText': __status.text, 'undo': true})
                    status.destroyStatus()
                }
            }

            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-delete'.concat(enabled ? "" : "-dimmed").concat(theme.inverted ? "-white" : "")
                text: qsTr('Delete the tweet')
                visible: status.user.id_str === oauth.user_id
                onClicked: status.destroyStatus()
            }

            /*MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-share'.concat(enabled ? "" : "-dimmed").concat(theme.inverted ? "-white" : "")
                text: qsTr('Share')
                onClicked: {
                    share.url = 'http://twitter.com/' + __status.user.screen_name + '/' + __status.id_str
                    share.mimeType = 'text/x-url'
                    share.title = __status.user.name
                    share.description = __status.text
                    share.share()
                }
            }*/

            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-tag'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Copy tweet text to clipboard')
                onClicked: {
                    clipboard.text = '';
                    clipboard.text = __status.text;
                    clipboard.selectAll();
                    clipboard.cut();
                }
            }
            MenuItemWithIcon {
                property url link: 'http://twitter.com/' + __status.user.screen_name + '/status/' + __status.id_str
                iconSource: 'image://theme/icon-m-toolbar-tag'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Copy tweet url to clipboard')
                onClicked: {
                    clipboard.text = '';
                    clipboard.text = link;
                    clipboard.selectAll();
                    clipboard.cut();
                }
            }
        }
    }

    tools: ToolBarLayout {
        id: toolBarLayout
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: {
                if (menu.status !== DialogStatus.Closed)
                    menu.close();
                pageStack.pop()
            }
        }

        ToolIcon {
            iconSource: theme.inverted ? '../images/reply-white.png' : '../images/reply.png'
            onClicked: {
                var user = '@' + __user.screen_name
                var users = __status.text.match(/@[A-Za-z0-9_]+/g)
                var statusText = user + ' '
                if (users) {
                    for (var i = 0; i < users.length; i++) {
                        if (users[i] !== user && users[i] !== '@' + oauth.screen_name && statusText.indexOf(users[i]) < 0)
                            statusText += users[i] + ' '
                    }
                }

                pageStack.push(tweetPage, {statusText: statusText, in_reply_to: __status})
            }
        }

        ToolIcon {
            id: btnFavorite
            iconSource: status.favorited ? 'image://theme/icon-m-toolbar-favorite-mark'.concat(theme.inverted ? "-white" : "") : 'image://theme/icon-m-toolbar-favorite-unmark'.concat(theme.inverted ? "-white" : "")
            onClicked: {
                if (status.favorited)
                    status.unfavorite()
                else
                    status.favorite()
            }

            states: [
                State {
                    name: "favorited"
                    when: status.favorited
                    PropertyChanges {
                        target: btnFavorite
                        iconSource: 'image://theme/icon-m-toolbar-favorite-mark'.concat(theme.inverted ? "-white" : "")
                    }
                }
            ]
        }

        ToolIcon {
            iconSource: theme.inverted ? '../images/retweet-white.png' : '../images/retweet.png'
            enabled: !status.retweeted
            opacity: enabled ? 1.0 : 0.5
            onClicked: {
                if (root.linkMenu) root.linkMenu.close()
                menu.close()
                if (__status.user.id_str == oauth.user_id || __status.retweeted) {
                    pageStack.push(tweetPage, {'statusText': ' RT @' + __status.user.screen_name + ': ' + __status.plaint_text, 'in_reply_to': __status})
                } else {
                    pageStack.push(tweetPage, {'in_reply_to': __status})
                }
            }
        }

        ToolIcon {
            platformIconId: "toolbar-view-menu"
            onClicked: {
                if (root.linkMenu) {
                    root.linkMenu.close()
                } else {
                    if (menu.status == DialogStatus.Closed)
                        menu.open()
                    else
                        menu.close()
                }
            }
        }
    }
}
