/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import Rocket 1.0
import QtMobility.location 1.1
import '../Components'
import '../Views'

Page {
    id: tweetPage

    Status {
        id: status
        onId_strChanged: {
            if (id_str.length > 0 && tweetPage.status === PageStatus.Active) {
                pageStack.pop(mainPage);
                positionSource.active = false;
            }
        }
    }

    PositionSource {
        id: positionSource
        updateInterval: 10000
        active: false
        property bool loading: active && (!position.latitudeValid && !position.longitudeValid)
        property bool valid: active && position.latitudeValid && position.longitudeValid
    }

    MusicUtils {
        id: musicUtils
        onTrackInfoReceived: {
            if(trackName)
                if (typeof trackName !== 'undefined') {
                    if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                        tweetPage.text += ' '
                    tweetPage.text += trackName + ' #NowPlaying'
                }
            else
                infoBanners.message({'text': qsTr("Music player is not running!")})
        }
    }

    property bool modified: false
    property string statusText
    property variant in_reply_to
    property bool retweet: typeof tweetPage.in_reply_to !== 'undefined' && typeof tweetPage.in_reply_to.id_str !== 'undefined' && tweetPage.in_reply_to.text.length > 0 && tweetPage.statusText == ''
    property bool reply: typeof tweetPage.in_reply_to !== 'undefined' && typeof tweetPage.in_reply_to.id_str !== 'undefined' && textArea.text.indexOf('@' + tweetPage.in_reply_to.user.screen_name) !== -1
    property bool first: true
    property bool undo: false
    property bool loading: false

    property string currentAction
    property alias text: textArea.text
    property variant media: []
    property variant location

    function uploadMedia(service) {
        var parameters;
        switch (parseInt(service)) {
            case 0:
            break;
            case 1: if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true
                parameters = {
                    'key': 'de0ec552b0ff9d153a71ec05d310ef1f'
                    , 'message': ''
                    , 'media': tweetPage.media[0]
                }
                twitpicLoader.upload('http://api.twitpic.com/2/upload.json', parameters)
            break;
            case 2:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true
                parameters = {
                    'key': '13BDNORUe2e5b6b444e91ed445c9a5d791d3dede'
                    , 'media': tweetPage.media[0]
                }
                yfrogLoader.upload('http://yfrog.com/api/xauth_upload', parameters)
            break;
            case 3:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true
                parameters = {
                    'key': '51LtGOU8eP6LtkuW'
                    , 'media': tweetPage.media[0]
                }
                mobypictureLoader.upload('https://api.mobypicture.com/2.0/upload.json', parameters)
            break;
            case 4:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true
                parameters = {
                    'media': tweetPage.media[0]
                }
                imglyLoader.upload('http://img.ly/api/2/upload.json', parameters)
            break;
            case 5:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true
                parameters = {
                    'media': tweetPage.media[0]
                }
                posterousLoader.upload('http://posterous.com/api2/upload.json', parameters)
            break;
            case 6:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true
                parameters = {
                    'media': tweetPage.media[0]
                }
                twitGooLoader.upload('http://twitgoo.com/api/upload', parameters)
            break;
            case 7:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true;
                parameters = {
                    'api_key': 'KpvgijfDRbVWnI6/VHIzfw'
                    , 'media': tweetPage.media[0]
                }
                pikchurLoader.upload('http://api.pikchur.com/simple/upload', parameters)
            break;
            case 8:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true;
                parameters = {
                    'api_key': '7a07cbe1887a6f661230edea3129aa60',
                    'media': tweetPage.media[0]
                }
                twitrpixLoader.upload('http://api.twitrpix.com/2/upload.xml', parameters)
            break;
            case 9:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true;
                parameters = {
                    'message': ' ',
                    'source': 'Rocket!',
                    'media': tweetPage.media[0]
                }
                twitvidLoader.upload('http://im.twitvid.com/api/uploadpic', parameters)
            break;
            case 10:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true;
                parameters = {
                    'media': tweetPage.media[0]
                }
                twippleLoader.upload('http://p.twipple.jp/api/upload2', parameters)
            break;
            case 11:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true;
                flickrUploader.uploadFlickr(tweetPage.media[0]);
            break;
            case 20:
                if (tweetPage.media.length !== 1) return;
                tweetPage.loading = true;
                parameters = {
                    'apikey': '',
                    'message': '',
                    'image': tweetPage.media[0]
                }
                screentweetLoader.upload('http://screentweet.com/api/uploadandpost/', parameters)
            break;
        }
    }

    onStatusChanged: {
        if (tweetPage.status === PageStatus.Active) {
            if (currentAction == '') {
                if (!tweetPage.retweet) {
                    textArea.forceActiveFocus()
                }
            } else if (currentAction == 'camera') {
            } else if (tweetPage.currentAction == 'gallery') {
                if (mediaSelected !== undefined) {
                    var media = tweetPage.media
                    media.push(mediaSelected)
                    mediaSelected = undefined
                    while (media.length > Math.max(1, configuration.max_media_per_upload))
                        media.shift()
                    tweetPage.media = media;
                    uploadMedia(settings.readData('ImageService/currentService', 0));
                }
                currentAction = ''
            } else if (currentAction == 'venue') {
            }
        }
    }

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top

        //text: qsTr('Tweet')

        centerBusyIndicator: true;

        busy: status.loading || positionSource.loading || tweetPage.loading
        newtweet: false
        homeButton: false

        SheetButton {
            id: btnCancel
            z: 901
            //width: 160
            Label {
                font.pixelSize: constants.fontLSmall
                font.capitalization: Font.MixedCase
                font.weight: Font.Bold
                anchors.centerIn: parent
                text: qsTr("Cancel")
                color: "white"
            }
            anchors.left: parent.left
            anchors.verticalCenter: header.verticalCenter
            anchors.margins: 10
            onClicked: {
                positionSource.active = false;
                if (mediaMenu.status !== DialogStatus.Closed)
                    mediaMenu.close()
                if (locationMenu.status !== DialogStatus.Closed)
                    locationMenu.close()
                textArea.platformCloseSoftwareInputPanel()
                if (undo)
                    pageStack.pop(mainPage)
                else
                pageStack.pop()
            }
            style: SheetButtonStyle {
                background: "image://theme/meegotouch-sheet-button-background-pressed"
                pressedBackground: "image://theme/meegotouch-sheet-button-background"
                disabledBackground: "image://theme/meegotouch-sheet-button-background-disabled"
            }
        }

        SheetButton {
            id: tweet
            z: 901
            //width: 160
            anchors.right: parent.right
            anchors.verticalCenter: header.verticalCenter
            anchors.margins: 10
            enabled: ((textArea.counter >= 0)&&(textArea.counter < 140))
            Label {
                id: lblTweet
                font.pixelSize: constants.fontLSmall
                font.capitalization: Font.MixedCase
                font.weight: Font.Bold
                horizontalAlignment: Text.AlignHCenter
                anchors.centerIn: parent
                text: qsTr('Tweet')
                color: "white"
            }
            //iconSource: verifyCredentials.profile_image_url
            onClicked: {
                var parameters = {'status': textArea.text, 'media': tweetPage.media}
                if (tweetPage.retweet)
                    status.retweetStatus({'id': tweetPage.in_reply_to.id_str})
                else {
                    if (tweetPage.reply)
                        parameters['in_reply_to_status_id'] = tweetPage.in_reply_to.id_str
                    if (positionSource.valid) {
                        parameters['_lat'] = positionSource.position.coordinate.latitude
                        parameters['_long'] = positionSource.position.coordinate.longitude
                    }
                    console.debug(parameters['_lat'], parameters['_long'])
                    status.updateStatus(parameters)
                }
            }
            platformStyle: SheetButtonAccentStyle { }
            /*style: SheetButtonStyle {
                background: "image://theme/meegotouch-sheet-button-background-pressed"
                pressedBackground: "image://theme/meegotouch-sheet-button-background"
                disabledBackground: "image://theme/meegotouch-sheet-button-background-disabled"
            }*/
            states: [
                State {
                    name: "retweet"
                    when: tweetPage.retweet
                    PropertyChanges {
                        target: lblTweet
                        text: qsTr('Retweet')
                    }
                },
                State {
                    name: "reply"
                    when: tweetPage.reply
                    PropertyChanges {
                        target: lblTweet
                        text: qsTr('Reply')
                    }
                }
            ]
        }

        states: [
            State {
                name: "retweet"
                when: tweetPage.retweet
                PropertyChanges {
                    target: header
                    //text: qsTr('Retweet')
                }
            },
            State {
                name: "reply"
                when: tweetPage.reply
                PropertyChanges {
                    target: header
                    //text: qsTr('Reply')
                }
            }
        ]
    }

    TextFieldStyle {
        id: textFieldStyle
        //textColor: ui.color_text_d
        textColor: constants.tweettext_color;
        background: "transparent"
        backgroundSelected: "transparent"
        backgroundError: "transparent"
    }

    function count(text, max, http_length, https_length) {
        var httpPattern = new RegExp(/^http:\/\/[-_.!~*'()a-zA-Z0-9;/?:@&=+$,%#]+$/);
        var httpsPattern = new RegExp(/^https:\/\/[-_.!~*'()a-zA-Z0-9;/?:@&=+$,%#]+$/);
        var length = max - text.length
        var chunk = text.split(/[^-_.!~*'()a-zA-Z0-9;/?:@&=+$,%#]/)
        for (var i = 0; i < chunk.length; i++) {
            var http = httpPattern.exec(chunk[i]);
            if (http !== null) {
                length = length + http[0].length - http_length
            }
            var https = httpsPattern.exec(chunk[i]);
            if (https !== null) {
                length = length + https[0].length - https_length
            }
        }

        return length
    }

    TextArea {
        id: textArea
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: media.top
        anchors.margins: 10
        //text: tweetPage.statusText.replace(/<a style="[^\"]+" href="[^\"]+" title="([^\"]+)">[^<]+<\/a>/g, "$1")
        text: tweetPage.statusText == '' && typeof tweetPage.in_reply_to !== 'undefined' ? tweetPage.in_reply_to.text : tweetPage.statusText
        textFormat: TextEdit.PlainText
        wrapMode: Text.WordWrap
        enabled: !status.loading
        style: textFieldStyle
        font.pixelSize: constants.fontDefault

        property string preedit: text.substring(0, cursorPosition) + platformPreedit + text.substring(cursorPosition)
        property int counter: count(preedit, 140 - tweetPage.media.length * configuration.characters_reserved_per_media, configuration.short_url_length, configuration.short_url_length_https)
        property int lastCursorPosition: 0
        property string text2: text
        onText2Changed: updateCompletion()
        onCursorPositionChanged: updateCompletion()
        onPreeditChanged: updateCompletion()
        onTextChanged: {
            text2 = text;
            if (textArea.text.match("([\.]{3})"))
            {
                if (cursorPosition !== 0)
                    lastCursorPosition = cursorPosition-2;
                textArea.text = textArea.text.replace(new RegExp("([\.]{3})",'g'), "…")
                textArea.cursorPosition = lastCursorPosition
            }
            else if (textArea.text.match("([-]{2})"))
            {
                if (cursorPosition !== 0)
                    lastCursorPosition = cursorPosition-1;
                textArea.text = textArea.text.replace(new RegExp("([-]{2})",'g'), "—")
                textArea.cursorPosition = lastCursorPosition
            }
        }
        function updateCompletion() {
            if (text2.length == cursorPosition || text2.charAt(cursorPosition) == ' ' || text2.charAt(cursorPosition) == '\n') {
                var screenName = new RegExp(/(@[a-zA-z0-9_]*)$/)
                var left = text2.substring(0, cursorPosition).concat(platformPreedit)
                if (screenName.test(left)) {
                    screenNamesView.filter = RegExp.$1
                } else {
                    screenNamesView.filter = ''
                }
            } else {
                screenNamesView.filter = ''
            }
        }

        Connections {
            target: textArea
            onActiveFocusChanged: {
                if (first) {
                    first = false
                    if (tweetPage.retweet) {
                        textArea.text = ' RT @' + tweetPage.in_reply_to.user.screen_name + ': ' + textArea.text
                        textArea.cursorPosition = 0;
                        tweetPage.retweet = false
                        lblTweet.text = qsTr("Retweet")
                    } else {
                        textArea.cursorPosition = textArea.text.length
                    }
                }

            }
        }
    }

    TwitUser {
        id: user
        screen_name: oauth.screen_name
    }

    UsersModel {
        id: friendModel
        FriendsModel {
            id: model
            user_id: user.id_str
            property variant ids: []
            onSizeChanged: {
                var ids = []
                for (var i = 0; i < model.size; i++) {
                    ids.push(model.get(i).id_str ? model.get(i).id_str : model.get(i).id)
                }
                //console.debug(ids)
                model.ids = ids
            }
        }

        Timer {
            running: model.ids.length > 0 && !friendModel.loading
            interval: 100
            repeat: false
            onTriggered: {
                console.debug('triggered')
                var ids = model.ids
                var user_id = []
                for (var i = 0; i < 100 && ids.length > 0; i++) {
                    user_id.push(ids.shift())
                }
                console.debug(user_id)
                model.ids = ids
                friendModel.user_id = user_id.join(',')
                friendModel.reload();
            }
        }
    }

    /*ListView{
        id: screenNamesView
        width: parent.width
        height: constant.graphicSizeMedium
        visible: filter.length > 0
        delegate: ListButton {
            height: ListView.view.height
            text: model.screen_name
            onClicked: {
                // FIXME
                var buttonText = model.screen_name;
                var lastWord = textArea.text.substring(textArea.text.lastIndexOf(" ") + 1, textArea.cursorPosition)
                textArea.text = textArea.text.replace(lastWord, buttonText + " ")
                textArea.cursorPosition = textArea.text.indexOf(buttonText) + buttonText.length + 1
                textArea.forceActiveFocus()
            }
        }
        orientation: ListView.Horizontal
        //spacing: constant.paddingSmall
        model: friendModel
    }*/

    CompletionView {
        id: screenNamesView
        anchors.bottom: statusBar.top
        anchors.left: parent.left
        anchors.right: parent.right
        model: friendModel
        icon: true
        z: 10
        //opacity: filter.length > 0 ? 1.0 : 0.0
        onClicked: {
            var screenName = new RegExp(/(@[a-zA-z0-9_]*)$/)
            if (screenName.test(textArea.text2.substring(0, textArea.cursorPosition))) {
                var len = RegExp.$1.length
                var left = textArea.text2.substring(0, textArea.cursorPosition)
                var center = candidate.substring(len - 1)
                if (left.length === len)
                    center = center.concat(' ')
                var right = textArea.text2.substring(textArea.cursorPosition)
//                                    textArea.preedit = ''
                textArea.text = left.concat(center).concat(right)
                textArea.forceActiveFocus()
                textArea.cursorPosition = left.length + center.length
                //textArea.platformPreedit = ''
            }
            screenNamesView.filter = ''
        }
    }

    ListView {
        id: media
        height: constants.listViewIconSize
        anchors.left: parent.left
        anchors.right: tweet.left
        anchors.bottom: statusBar.top
        anchors.margins: 10
        model: tweetPage.media
        orientation: ListView.Horizontal
        delegate: Image {
            id: thumbnail
            height: ListView.view.height
            width: height
            source: model.modelData
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    var media = []
                    for (var i = 0; i < tweetPage.media.length; i++) {
                        if (tweetPage.media[i] != thumbnail.source) {
                            media.push(tweetPage.media[i])
                        }
                    }
                    tweetPage.media = media
                }
            }
        }

    }

    Item {
        id: menuArea
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: statusBar.top
    }

    Menu {
        id: mediaMenu
        visualParent: menuArea
        MenuLayout {
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-add'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Camera')
                enabled: false
                onClicked: {
                    tweetPage.currentAction = 'camera'
                    mediaSelected = undefined
                    pageStack.push(cameraPage)
                }
            }

            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-gallery'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Gallery')
                onClicked: {
                    tweetPage.currentAction = 'gallery'
                    mediaSelected = undefined
                    pageStack.push(selectMediaPage)
                }
            }
        }
    }

    Menu {
        id: locationMenu
        visualParent: menuArea
        MenuLayout {
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-common-location'.concat(positionSource.valid ? '-selected' : (theme.inverted ? "-inverse" : ""))
                text: qsTr('Current location')
                onClicked: positionSource.active = !positionSource.active

            }

            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-home'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Venue')
                enabled: false
                onClicked: {
                    tweetPage.currentAction = 'venue'
                    locationSelected = undefined
                    pageStack.push(selectVenuePage)
                }
            }
        }
    }

    function setUploadProgress(progress){
        uploadProgress.value = progress
    }

    PhotoUploader {
        id: twitpicLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            var json = JSON.parse(result)
            if (ok && typeof json.url !== 'undefined') {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += json.url
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: yfrogLoader
        verifyCredentialsFormat: 'xml'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            if (ok) {
                xmlParser.xml = result
            } else {
                tweetPage.loading = false
            }
        }
    }
    XmlListModel {
        id: xmlParser
        query: '/rsp'
        XmlRole { name: 'url'; query: 'mediaurl/string()' }
        onCountChanged: {
            if (count == 1) {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += get(0).url
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: mobypictureLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            var json = JSON.parse(result)
            if (ok && typeof json.media.mediaurl !== 'undefined') {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += json.media.mediaurl
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: imglyLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            var json = JSON.parse(result)
            if (ok && typeof json.url !== 'undefined') {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += json.url
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: posterousLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            var json = JSON.parse(result)
            if (ok && typeof json.url !== 'undefined') {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += json.url
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: twitGooLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            if (ok) {
                twitGooXmlParser.xml = result
            } else {
                tweetPage.loading = false
            }
        }
    }
    XmlListModel {
        id: twitGooXmlParser
        query: '/rsp'
        XmlRole { name: 'url'; query: 'mediaurl/string()' }
        onCountChanged: {
            if (count == 1) {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += get(0).url
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: pikchurLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            if (ok) {
                pikchurXmlParser.xml = result
            } else {
                tweetPage.loading = false
            }
        }
    }
    XmlListModel {
        id: pikchurXmlParser
        query: '/rsp'
        XmlRole { name: 'mediaurl'; query: 'mediaurl/string()' }
        onCountChanged: {
            if (count == 1) {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += get(0).mediaurl
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: twitrpixLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            if (ok) {
                twitrpixXmlParser.xml = result
            } else {
                tweetPage.loading = false
            }
        }
    }
    XmlListModel {
        id: twitrpixXmlParser
        query: '/response/media'
        XmlRole { name: 'url'; query: 'url/string()' }
        onCountChanged: {
            if (count == 1) {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += get(0).url
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: twitvidLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            if (ok) {
                twitvidXmlParser.xml = result
            } else {
                tweetPage.loading = false
            }
        }
    }
    XmlListModel {
        id: twitvidXmlParser
        query: '/rsp'
        XmlRole { name: 'media_url'; query: 'media_url/string()' }
        onCountChanged: {
            if (count == 1) {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += get(0).media_url
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: flickrUploader
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            if (ok) {
                flickrXmlParser.xml = result
            } else {
                tweetPage.loading = false
            }
        }
    }
    XmlListModel {
        id: flickrXmlParser
        query: '/rsp'
        XmlRole { name: 'mediaurl'; query: 'mediaurl/string()' }
        onCountChanged: {
            if (count == 1) {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += get(0).mediaurl
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: twippleLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            if (ok) {
                twippleXmlParser.xml = result
            } else {
                tweetPage.loading = false
            }
        }
    }
    XmlListModel {
        id: twippleXmlParser
        query: '/rsp'
        XmlRole { name: 'mediaurl'; query: 'mediaurl/string()' }
        onCountChanged: {
            if (count == 1) {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += get(0).mediaurl
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    PhotoUploader {
        id: screentweetLoader
        verifyCredentialsFormat: 'json'
        onProgressChanged: setUploadProgress(progress);
        onDone: {
            if (ok) {
                screentweetXmlParser.xml = result
            } else {
                tweetPage.loading = false
            }
        }
    }
    XmlListModel {
        id: screentweetXmlParser
        query: '/rsp'
        XmlRole { name: 'shorturl'; query: 'shorturl/string()' }
        onCountChanged: {
            if (count == 1) {
                if (tweetPage.text.length > 0 && tweetPage.text.substring(tweetPage.text.substring(tweetPage.text.length - 1, 1) !== ' '))
                    tweetPage.text += ' '
                tweetPage.text += get(0).shorturl
                var media = []
                tweetPage.media = media
            }
            tweetPage.loading = false
        }
    }

    Menu {
        id: uploadMenu
        visualParent: menuArea
        MenuLayout {
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-home'.concat(theme.inverted ? "-white" : "")
                text: qsTr('TwitPic')
                enabled: true
                onClicked: {
                    if (tweetPage.media.length !== 1) return;
                    tweetPage.loading = true
                    var parameters = {
                        'key': 'de0ec552b0ff9d153a71ec05d310ef1f'
                        , 'message': ''
                        , 'media': tweetPage.media[0]
                    }
                    twitpicLoader.upload('http://api.twitpic.com/2/upload.json', parameters)
                }
            }
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-home'.concat(theme.inverted ? "-white" : "")
                text: qsTr('yfrog')
                enabled: true
                onClicked: {
                    if (tweetPage.media.length !== 1) return;
                    tweetPage.loading = true
                    var parameters = {
                        'key': '13BDNORUe2e5b6b444e91ed445c9a5d791d3dede'
                        , 'media': tweetPage.media[0]
                    }
                    yfrogLoader.upload('http://yfrog.com/api/xauth_upload', parameters)
                }
            }
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-home'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Mobypicture')
                enabled: true
                onClicked: {
                    if (tweetPage.media.length !== 1) return;
                    tweetPage.loading = true
                    var parameters = {
                        'key': '51LtGOU8eP6LtkuW'
                        , 'media': tweetPage.media[0]
                    }
                    mobypictureLoader.upload('https://api.mobypicture.com/2.0/upload.json', parameters)
                }
            }
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-home'.concat(theme.inverted ? "-white" : "")
                text: qsTr('img.ly')
                enabled: true
                onClicked: {
                    if (tweetPage.media.length !== 1) return;
                    tweetPage.loading = true
                    var parameters = {
                        'media': tweetPage.media[0]
                    }
                    imglyLoader.upload('http://img.ly/api/2/upload.json', parameters)
                }
            }
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-home'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Posterous')
                enabled: true
                onClicked: {
                    if (tweetPage.media.length !== 1) return;
                    tweetPage.loading = true
                    var parameters = {
                        'media': tweetPage.media[0]
                    }
                    posterousLoader.upload('http://posterous.com/api2/upload.json', parameters)
                }
            }
            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-home'.concat(theme.inverted ? "-white" : "")
                text: qsTr('Twitgoo')
                enabled: true
                onClicked: {
                    if (tweetPage.media.length !== 1) return;
                    tweetPage.loading = true
                    var parameters = {
                        'media': tweetPage.media[0]
                    }
                    twitGooLoader.upload('http://twitgoo.com/api/upload', parameters)
                }
            }
        }
    }

    ProgressBar {
         id: uploadProgress
         width: parent.width
         minimumValue: 0
         maximumValue: 100
         anchors.bottom: header.bottom
         visible: (uploadProgress.value != minimumValue && uploadProgress.value != maximumValue)
     }

    ToolBar {
        id: statusBar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        tools: ToolBarLayout {
            Label {
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                text: textArea.counter;
                platformStyle: LabelStyle { fontPixelSize: constants.fontDefault }
            }
            ToolIcon {
                id: btnSelectUsername
                anchors.left: parent.left
                iconSource: theme.inverted ? '../images/usernames-white.png' : '../images/usernames.png'
                onClicked: {
                    var screenName = new RegExp(/(@[a-zA-z0-9_]*)$/)
                    if (screenName.test(textArea.text2.substring(0, textArea.cursorPosition))) {
                        var left = textArea.text2.substring(0, textArea.cursorPosition)
                        textArea.text = left.concat(' @')
                        textArea.forceActiveFocus()
                        textArea.cursorPosition = left.length + 2
                    } else {
                        var left2 = textArea.text2.substring(0, textArea.cursorPosition)
                        if (left2.length === 0) {
                            textArea.text = left2.concat('@')
                            textArea.forceActiveFocus()
                            textArea.cursorPosition = left2.length + 1
                        } else {
                            textArea.text = left2.concat(' @')
                            textArea.forceActiveFocus()
                            textArea.cursorPosition = left2.length + 2
                        }
                    }
                }
            }
            ToolIcon {
                id: btnGallery
                anchors.left: btnSelectUsername.right
                platformIconId: "toolbar-gallery"
                onClicked: {
                    tweetPage.currentAction = 'gallery'
                    mediaSelected = undefined
                    pageStack.push(selectMediaPage)
                }
            }
            ToolIcon {
                id: btnCamera
                anchors.left: btnGallery.right
                platformIconId: "toolbar-camera"
                onClicked: {
                    //uploadMedia(settings.readData('ImageService/currentService', 0));
                    //eventFeed
                    var component = eventFeed.createObject(window)
                    component.icon = thumbnailCacher.get("http://api.twitter.com/1/users/profile_image?screen_name=ukhamitov&size=normal");
                    component.title = "@ukhamitov";
                    component.body = "New item. Íîâûé ýëåìåíò."
                    component.action = 'rocket://status/268731292445724673';
                    var currentDate = new Date()
                    component.timestamp = currentDate
                    component.publish()

                    /*tweetPage.currentAction = 'camera'
                    mediaSelected = undefined
                    pageStack.push(cameraPage)*/
                }
                visible: false;
            }
            ToolIcon {
                id: btnNowPlaying
                anchors.right: btnLocation.left
                platformIconId: "toolbar-audio"
                onClicked: {
                    textArea.forceActiveFocus();
                    musicUtils.getCurrentTrack();
                }
            }
            ToolIcon {
                id: btnLocation
                anchors.right: parent.right
                iconSource: 'image://theme/icon-s-location-picker'.concat(theme.inverted ? "-inverse" : "")
                enabled: verifyCredentials.geo_enabled
                onClicked: {
                    positionSource.active = !positionSource.active;
                    textArea.forceActiveFocus();
                    /*if ((constants.locationAlwaysOn) && (positionSource.active)) {
                        settings.saveData('Application/locationAlwaysOn', false)
                    }*/
                }
                states: [
                    State {
                        name: "active"
                        when: positionSource.valid
                        PropertyChanges {
                            target: btnLocation
                            iconSource: 'image://theme/icon-s-location-picker-selected'
                        }
                    }
                ]
                Component.onCompleted: {
                    if (constants.locationAlwaysOn) {
                        positionSource.active = true;
                    }
                }
            }
        }
    }
}
