﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import TwitterCore 1.0
import '../Components'
import '../Delegates'

Page {
    id: root

    property alias id_str: user.id_str
    property alias screen_name: user.screen_name

    TwitUser {
        id: user
        id_str: root.id_str
        onFollowingChanged: {
            if (window.friends.length === 0) return

            var friends = window.friends
            if (following) {
                friends.push(user.id_str)
            } else if (friends.indexOf(user.id_str) > -1) {
                friends.splice(friends.indexOf(user.id_str), 1)
            }
            window.friends = friends
        }
    }

    TitleBar {
        id: header
        z: 10000
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        busy: user.loading
        opacity: 1
        user: user
        newtweet: false
        text: "@"+user.screen_name ? "@"+user.screen_name : qsTr("User")
    }

    ShowFriendships {
        id: showFriendships
        source_id: oauth.user_id
        target_id: root.id_str
    }

    Flickable {
        anchors.top: header.bottom
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 74
        anchors.left: parent.left
        anchors.right: parent.right

        contentHeight: userInfoBackground.height

        Rectangle {
            id: userInfoBackground
            anchors.right: parent.right
            anchors.left: parent.left
            height: clm.height+preview.height
            color: "transparent"
            UserDetailDelegate {
                id: preview
                //anchors.top: header.bottom
                anchors.left: parent.left
                anchors.right: parent.right
                user: user
                onLinkActivated: {
                    switch (true) {
                    case /^search:/.test(link):
                        pageStack.push(searchPage, {query: link.substring(7)})
                        break
                    case /^user:/.test(link):
                        pageStack.push(userPage, {id_str: link.substring(5)})
                        break
                    default:
                        ActionHandler.openUrlExternally(link)
                        break
                    }
                }
                onHeightChanged: {
                    userInfoBackground.height = clm.height+preview.height
                }
            }
            
            Rectangle {
                id: infoPanel
                anchors.top: preview.bottom
                height: 64
                width: parent.width
                gradient: Gradient {
                    GradientStop {
                        color: theme.inverted ? "#393939" : "#c6c6c6"
                        position: 0
                    }
                    GradientStop {
                        color: theme.inverted ? "#252525" : "#dadada"
                        position: 1
                    }
                }
                Rectangle {
                    anchors.top: parent.top
                    height: 1
                    width: parent.width
                    color: theme.inverted ? "#000000" : "#ffffff"
                }
                Rectangle {
                    anchors.top: parent.top
                    anchors.topMargin: 1
                    height: 1
                    width: parent.width
                    color: theme.inverted ? "#494949" : "#b6b6b6"
                }
                Row {
                    width: parent.width
                    height: parent.height
                    Button {
                        height: parent.height
                        width: parent.width/4
                        platformStyle: ButtonStyle {
                            background: "transparent"
                            pressedBackground: "transparent"
                            checkedBackground: background
                        }
                        Label {
                            id: lblStatusesCount
                            anchors.top: parent.top
                            anchors.topMargin: 4
                            anchors.horizontalCenter: lblTweets.horizontalCenter
                            text: user.statuses_count
                        }
                        Label {
                            id: lblTweets
                            anchors.top: lblStatusesCount.bottom
                            anchors.horizontalCenter: parent.horizontalCenter
                            text: qsTr("Tweets")
                            color: theme.inverted ? "#808080" : "#7f7f7f"
                            font.pixelSize: constants.fontSmall
                        }
                        onClicked: pageStack.push(userTimelinePage, {id_str: user.id_str, screen_name: user.screen_name})
                    }
                    Button {
                        height: parent.height
                        width: parent.width/4
                        platformStyle: ButtonStyle {
                            background: "transparent"
                            pressedBackground: "transparent"
                            checkedBackground: background
                        }
                        Label {
                            id: lblFavouritesCount
                            anchors.top: parent.top
                            anchors.topMargin: 4
                            anchors.horizontalCenter: lblFavorites.horizontalCenter
                            text: user.favourites_count
                        }
                        Label {
                            id: lblFavorites
                            anchors.top: lblFavouritesCount.bottom
                            anchors.horizontalCenter: parent.horizontalCenter
                            text: qsTr("Favorites")
                            color: theme.inverted ? "#808080" : "#7f7f7f"
                            font.pixelSize: constants.fontSmall
                        }
                        onClicked: pageStack.push(favouritesPage, {id_str: user.id_str, screen_name: user.screen_name})
                    }
                    Button {
                        height: parent.height
                        width: parent.width/4
                        platformStyle: ButtonStyle {
                            background: "transparent"
                            pressedBackground: "transparent"
                            checkedBackground: background
                        }
                        Label {
                            id: lblFollowingCount
                            anchors.top: parent.top
                            anchors.topMargin: 4
                            anchors.horizontalCenter: lblFollowing.horizontalCenter
                            text: user.friends_count
                        }
                        Label {
                            id: lblFollowing
                            anchors.top: lblFollowingCount.bottom
                            anchors.horizontalCenter: parent.horizontalCenter
                            text: qsTr("Following")
                            color: theme.inverted ? "#808080" : "#7f7f7f"
                            font.pixelSize: constants.fontSmall
                        }
                        onClicked: pageStack.push(followingPage, {user: user})
                    }
                    Button {
                        height: parent.height
                        width: parent.width/4
                        platformStyle: ButtonStyle {
                            background: "transparent"
                            pressedBackground: "transparent"
                            checkedBackground: background
                        }
                        Label {
                            id: lblFollowersCount
                            anchors.top: parent.top
                            anchors.topMargin: 4
                            anchors.horizontalCenter: lblFollowers.horizontalCenter
                            text: user.followers_count
                        }
                        Label {
                            id: lblFollowers
                            anchors.top: lblFollowersCount.bottom
                            anchors.horizontalCenter: parent.horizontalCenter
                            text: qsTr("Followers")
                            color: theme.inverted ? "#808080" : "#7f7f7f"
                            font.pixelSize: constants.fontSmall
                        }
                        onClicked: pageStack.push(followersPage, {user: user})
                    }
                    /*Button {
                        height: parent.height
                        width: parent.width/4
                        platformStyle: ButtonStyle {
                            background: "transparent"
                            pressedBackground: "transparent"
                            checkedBackground: background
                        }
                        Label {
                            id: lblListedCount
                            anchors.top: parent.top
                            anchors.topMargin: 4
                            anchors.horizontalCenter: lblListed.horizontalCenter
                            text: user.listed_count
                        }
                        Label {
                            id: lblListed
                            anchors.top: lblListedCount.bottom
                            anchors.horizontalCenter: parent.horizontalCenter
                            text: qsTr("Listed")
                            color: "#808080"
                            font.pixelSize: constants.fontSmall
                        }
                        onClicked: pageStack.push(listedPage, {id_str: user.id_str, title: '@' + user.screen_name})
                    }*/
                }
            }
            
            Column {
                id: clm
                anchors.top: preview.bottom
                anchors.topMargin: 7
                width: root.width
                spacing: 16

                /*ButtonColumn {
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    anchors.right: parent.right
                    anchors.rightMargin: 16
                    Button {
                        height: 70
                        enabled: false;
                        platformStyle: ButtonStyle {
                             checkedBackground: background
                        }
                        Label {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 32
                            text: typeof showFriendships.relationship.target !== 'undefined' && showFriendships.relationship.target.following ? qsTr("User follows you") : qsTr("User does not follow you")
                            font.bold: true
                        }
                    }
                }

                ButtonColumn {
                    id: content
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    anchors.right: parent.right
                    anchors.rightMargin: 16
                    Button {
                        height: 70
                        platformStyle: ButtonStyle {
                             checkedBackground: background
                        }
                        Label {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 32
                            text: qsTr("Tweets")
                            font.bold: true
                        }
                        Label {
                            anchors.right: parent.right
                            anchors.rightMargin: 32
                            anchors.verticalCenter: parent.verticalCenter
                            text: user.statuses_count
                            color: "#9c9a9c"
                        }
                        onClicked: pageStack.push(userTimelinePage, {'id_str': user.id_str, 'screen_name': user.screen_name})
                    }
                    Button {
                        height: 70
                        platformStyle: ButtonStyle {
                             checkedBackground: background
                        }
                        Label {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 32
                            text: qsTr("Favorites")
                            font.bold: true
                        }
                        Label {
                            anchors.right: parent.right
                            anchors.rightMargin: 32
                            anchors.verticalCenter: parent.verticalCenter
                            text: user.favourites_count
                            color: "#9c9a9c"
                        }
                        onClicked: pageStack.push(favouritesPage, {'id_str': user.id_str, 'screen_name': user.screen_name})
                    }
                }

                ButtonColumn {
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    anchors.right: parent.right
                    anchors.rightMargin: 16
                    Button {
                        height: 70
                        platformStyle: ButtonStyle {
                             checkedBackground: background
                        }
                        Label {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 32
                            text: qsTr("Following")
                            font.bold: true
                        }
                        Label {
                            anchors.right: parent.right
                            anchors.rightMargin: 32
                            anchors.verticalCenter: parent.verticalCenter
                            text: user.friends_count
                            color: "#9c9a9c"
                        }
                        onClicked: pageStack.push(followingPage, {'user': user})
                    }
                    Button {
                        height: 70
                        platformStyle: ButtonStyle {
                             checkedBackground: background
                        }
                        Label {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 32
                            text: qsTr("Followers")
                            font.bold: true
                        }
                        Label {
                            anchors.right: parent.right
                            anchors.rightMargin: 32
                            anchors.verticalCenter: parent.verticalCenter
                            text: user.followers_count
                            color: "#9c9a9c"
                        }
                        onClicked: pageStack.push(followersPage, {'user': user})
                    }
                }
                }*/

                /*
                ButtonColumn {
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    anchors.right: parent.right
                    anchors.rightMargin: 16
                    Button {
                        height: 70
                        platformStyle: ButtonStyle {
                             checkedBackground: background
                        }
                        Label {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 32
                            text: qsTr("Listed")
                            font.bold: true
                        }
                        Label {
                            anchors.right: parent.right
                            anchors.rightMargin: 32
                            anchors.verticalCenter: parent.verticalCenter
                            text: user.listed_count
                            color: "#9c9a9c"
                        }
                        onClicked: pageStack.push(listedPage, {'id_str': user.id_str, 'title': '@' + user.screen_name})
                    }

                    Button {
                        height: 70
                        platformStyle: ButtonStyle {
                             checkedBackground: background
                        }
                        Label {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 32
                            text: qsTr("Lists")
                            font.bold: true
                        }
                        onClicked: pageStack.push(listsPage, {'id_str': user.id_str, 'title': '@' + user.screen_name})
                    }
                }
                }*/
            }
        }
    }

    Menu {
        id: menu
        visualParent: root.pageStack
        MenuLayout {
            MenuItemWithIcon {
                property bool muted: window.filters.indexOf('@'.concat(user.screen_name)) > -1
                iconSource: 'image://theme/icon-m-toolbar-volume'.concat(muted ? '' : '-off').concat(theme.inverted ? "-white" : "")
                text: muted ? qsTr('Unmute @%1').arg(user.screen_name) : qsTr('Mute @%1').arg(user.screen_name)
                onClicked: {
                    var filters = window.filters
                    if (muted) {
                        var index = filters.indexOf('@'.concat(user.screen_name))
                        while (index > -1) {
                            filters.splice(index, 1)
                            index = filters.indexOf('@'.concat(user.screen_name))
                        }
                    } else {
                        filters.unshift('@'.concat(user.screen_name))
                    }
                    window.filters = filters
                }
            }

            MenuItemWithIcon {
                iconSource: 'image://theme/icon-m-toolbar-favorite-'.concat(user.following ? 'mark' : 'unmark').concat(theme.inverted ? "-white" : "")
                text: user.following ? qsTr('Unfollow @%1').arg(user.screen_name) : qsTr('Follow @%1').arg(user.screen_name)
                onClicked: {
                    if (user.following)
                        user.unfollow()
                    else
                        user.follow()
                }
            }

            MenuItem {
                text: user.blocking ? qsTr('Unblock @%1').arg(user.screen_name) : qsTr('Block @%1').arg(user.screen_name)
                onClicked: {
                    if (user.blocking)
                        user.unblock()
                    else
                        user.block()
                }
            }

            MenuItem {
                text: qsTr('Report @%1 for spam').arg(user.screen_name)
                onClicked: user.reportForSpam()
            }
        }
    }

    tools: ToolBarLayout {
        id: toolBarLayout
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: {
                menu.close()
                root.pageStack.pop()
            }
        }
        ToolIcon {
            platformIconId: "toolbar-send-email"
            onClicked: {
                menu.close()
                root.pageStack.push(tweetPage, {statusText: '@' + user.screen_name + ' '})
            }
        }
        ToolIcon {
            opacity: enabled ? 1.0 : 0.5
            enabled: showFriendships.relationship.target.following
            platformIconId: "toolbar-send-sms"
            onClicked: {
                menu.close()
                root.pageStack.push(sendDirectMessagePage, {to: user})
            }
        }
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            opacity: enabled ? 1.0 : 0.5
            onClicked: {
                if (menu.status == DialogStatus.Closed)
                    menu.open()
                else
                    menu.close()
            }
        }
    }
}
