﻿/* © Webpoint Studio, 2008-2013
 *
 * Site:   http://webpointstudio.ru
 * E-mail: info@webpointstudio.ru
 */

/* Copyright (c) 2012 QNeptunea Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the QNeptunea nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL QNEPTUNEA BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
import QtQuick 1.1
import com.nokia.meego 1.0
import '../Components'

Page {
    id: pocketPage

    property string apiUrl: 'https://readitlaterlist.com/v2/auth'
    property string apiKey: 'ebyd2r39Tdk37q14fuAy768t27g2I889'
    property bool signedIn: settings.readData('getpocket.com/username', '').length > 0 && settings.readData('getpocket.com/password', '').length > 0

    TitleBar {
        id: header
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        newtweet: false
        text: qsTr('Pocket account')
    }

    Flickable {
        anchors.top: header.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        contentHeight: content.height
        clip: true
        Rectangle {
            id: content
            anchors.fill: parent
            color: "transparent"
            Image {
                id: logo
                x: 17
                y: 17
                width: 80
                height: 80
                source: "qrc:/qml/rocket/images/getpocket.png"
            }

            Column {
                id: aboutText
                anchors.left: logo.right
                anchors.leftMargin: 17
                anchors.top: parent.top
                anchors.topMargin: 15
                spacing: 10
                Label {
                    text: qsTr("Pocket (Formerly Read It Later)")
                }
                Label {
                    width: parent.width
                    text: qsTr("When you find something online that you want to view later, put it in Pocket.")
                    wrapMode: Text.WordWrap
                }
                Label {
                    text: "© 2012 Read It Later, Inc"
                }
            }
            Column {
                id: accountDetail
                anchors.left: parent.left
                anchors.leftMargin: 17
                anchors.right: parent.right
                anchors.rightMargin: 17
                anchors.top: aboutText.bottom
                anchors.topMargin: 15
                spacing: 10

                Label {
                    text: qsTr("Username:")
                }

                TextField {
                    id: edtUsername
                    width: parent.width
                    text: settings.readData('getpocket.com/username', '')
                    inputMethodHints: Qt.ImhNoAutoUppercase | Qt.ImhEmailCharactersOnly | Qt.ImhNoPredictiveText;
                    platformSipAttributes: SipAttributes {
                        actionKeyLabel: qsTr('Next')
                    }
                    Keys.onReturnPressed: edtPassword.forceActiveFocus()
                }

                Label {
                    text: qsTr("Password:")
                }

                TextField {
                    id: edtPassword
                    width: parent.width
                    text: settings.readData('getpocket.com/password', '')
                    maximumLength: 100
                    echoMode: TextInput.Password
                    inputMethodHints: Qt.ImhNoAutoUppercase | Qt.ImhNoPredictiveText;
                    platformSipAttributes: SipAttributes {
                        actionKeyLabel: qsTr('Sign In')
                    }
                    Keys.onReturnPressed: btnSignIn.signIn()
                }

                Button {
                    id: btnSignIn
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: qsTr("Sign In")
                    onClicked: {
                        if (btnSignIn.state == 'signedIn')
                            btnSignIn.signOut()
                        else
                            btnSignIn.signIn()
                    }

                    states: [
                        State {
                            name: 'signedIn'
                            when: pocketPage.signedIn
                            PropertyChanges {
                                target: btnSignIn
                                text: qsTr('Sign Out')
                            }
                        }
                    ]

                    function signIn() {
                        var url = apiUrl.concat('?apikey=').concat(apiKey).concat('&username=').concat(edtUsername.text).concat('&password=').concat(edtPassword.text)

                        console.debug(url)
                        var request = new XMLHttpRequest();
                        request.open('GET', url);
                        request.onreadystatechange = function() {
                            switch (request.readyState) {
                            case XMLHttpRequest.HEADERS_RECEIVED:
                                break
                            case XMLHttpRequest.LOADING:
                                break
                            case XMLHttpRequest.DONE: {
                                if (request.status === 200) {
                                    settings.saveData('getpocket.com/username', edtUsername.text)
                                    settings.saveData('getpocket.com/password', edtPassword.text)
                                    pageStack.pop()
                                    infoBanners.message("Successful authentication")
                                } else {
                                    infoBanners.message("ERROR: "+request.responseText)
                                }
                                //root.busy = false
                                break }
                            case XMLHttpRequest.ERROR: {
                                infoBanners.message("ERROR: "+request.responseText)
                                //root.busy = false
                                break }
                            }
                        };
                        request.send();
                    }

                    function signOut() {
                        edtUsername.text = ''
                        edtPassword.text = ''
                        settings.saveData('getpocket.com/username', '')
                        settings.saveData('getpocket.com/password', '')
                        pocketPage.signedIn = false
                    }
                }
            }
        }
    }

    tools: ToolBarLayout {
        id: toolBar
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: {
                pageStack.pop()
            }
        }
    }
}
